@@ -2,7 +2,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: LLkParser.cpp 312 2008-07-05 17:40:12Z vadim $
+ * $Id: LLkParser.cpp 646 2008-11-13 06:33:44Z vadim $
  */
 
 #include "antlr/LLkParser.hpp"
@@ -80,6 +80,16 @@ void LLkParser::traceOut(const char* rname)
 	traceDepth--;
 }
 
+RefToken LLkParser::LT(unsigned int i)
+{
+    assert(this!=NULL);
+    assert(inputState!=NULL);
+    TokenBuffer &tb = inputState->getInput();
+    assert(&tb!=NULL);
+    return tb.LT(i);
+}
+
+
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 }
 #endif
