@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ACL.h 312 2008-07-05 17:40:12Z vadim $
+  $Id: ACL.h 1152 2009-07-13 15:45:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -73,9 +73,9 @@ class ciscoACL {
 
     /*
      * Adds remark to access list. Checks and adds each remark only
-     * once. We use rule labels for remarks
+     * once. We use rule labels and comments for remarks
      */
-    std::string addRemark(const std::string &rl);
+    std::string addRemark(const std::string &rl, const std::string &comment);
 
     void setName(const std::string &s) { _name=s; }
     std::string name() { return _name; }
