@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_cisco.cpp 709 2008-12-25 20:38:53Z vadim $
+  $Id: PolicyCompiler_cisco.cpp 1152 2009-07-13 15:45:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -126,7 +126,7 @@ void PolicyCompiler_cisco::addDefaultPolicyRule()
         r->setLogging(false);
         r->setDirection(PolicyRule::Inbound);
         r->setPosition(-1);
-        r->setComment("   backup ssh access rule ");
+//        r->setComment("   backup ssh access rule ");
         r->setHidden(true);
         r->setFallback(false);
         r->setLabel("backup ssh access rule");
