@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_cisco_acls.cpp 338 2008-07-07 18:29:33Z vadim $
+  $Id: PolicyCompiler_cisco_acls.cpp 709 2008-12-25 20:38:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -87,8 +87,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionBySrc::processNext()
             assert(ifs);
             if (ifs->isUnprotected()) continue;   // skip!
 
-            PolicyRule *new_rule = PolicyRule::cast(
-                compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            PolicyRule *new_rule = compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId(intf_id);
@@ -139,8 +138,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionByDst::processNext()
             assert(ifs);
             if (ifs->isUnprotected()) continue;   // skip!
 
-            PolicyRule *new_rule = PolicyRule::cast(
-                compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            PolicyRule *new_rule = compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId(intf_id);
@@ -176,8 +174,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
 
         if (rule->getDirection()==PolicyRule::Both)
         {
-            new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
+            new_rule =compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
@@ -185,8 +182,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
             new_rule->setBool("interface_and_direction_set",true);
             tmp_queue.push_back(new_rule);
 
-            new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
+            new_rule =compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
@@ -195,8 +191,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
             tmp_queue.push_back(new_rule);
         } else
         {
-            new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
+            new_rule =compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
