@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: AddressRangeDialog.cpp 353 2008-07-13 01:26:39Z vadim $
+  $Id: AddressRangeDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -62,6 +62,11 @@ AddressRangeDialog::~AddressRangeDialog()
     delete m_dialog;
 }
 
+void AddressRangeDialog::getHelpName(QString *str)
+{
+    *str = "AddressRangeDialog";
+}
+
 void AddressRangeDialog::loadFWObject(FWObject *o)
 {
     obj=o;
