@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: CustomServiceDialog.cpp 717 2008-12-29 17:49:20Z vadim $
+  $Id: CustomServiceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -62,6 +62,11 @@ CustomServiceDialog::~CustomServiceDialog()
     delete m_dialog;
 }
 
+void CustomServiceDialog::getHelpName(QString *str)
+{
+    *str = "CustomServiceDialog";
+}
+
 void CustomServiceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
