@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.cpp 743 2009-01-19 08:50:59Z vadim $
+  $Id: FWBSettings.cpp 971 2009-05-27 20:40:51Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@
 #include <qapplication.h>
 #include <QDir>
 #include <QDesktopWidget>
+#include <QUuid>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -78,6 +79,9 @@ const char* objTooltips = SETTINGS_PATH_PREFIX "/UI/objTooltips";
 const char* tooltipDelay = SETTINGS_PATH_PREFIX "/UI/tooltipDelay";
 
 const char* emptyRCSLog = SETTINGS_PATH_PREFIX "/RCS/emptyLog";
+const char* rcsFilePreviewStyle = SETTINGS_PATH_PREFIX "/RCS/FilePreviewStyle";
+const char* rcsFilePreviewSortColumn = SETTINGS_PATH_PREFIX "/RCS/FilePreviewSortColumn";
+
 const char* dontSaveStdLib = SETTINGS_PATH_PREFIX "/DataFormat/dontSaveStdLib";
 const char* WindowGeometrySetpath= SETTINGS_PATH_PREFIX "/Layout/";
 const char* screenPositionSetpath= SETTINGS_PATH_PREFIX "/ScreenPos/";
@@ -96,6 +100,8 @@ const char* clipComment = SETTINGS_PATH_PREFIX "/UI/ClipComment";
 const char* checkUpdates = SETTINGS_PATH_PREFIX "/UI/CheckUpdates";
 const char* checkUpdatesProxy = SETTINGS_PATH_PREFIX "/UI/CheckUpdatesProxy";
 
+const char* appGUID = SETTINGS_PATH_PREFIX "/ApplicationGUID";
+
 FWBSettings::FWBSettings() :
     QSettings(QSettings::UserScope, "netcitadel.com", "Firewall Builder")
 {
@@ -114,6 +120,13 @@ void FWBSettings::init()
 {
     bool ok=false;
 
+    ok = contains(appGUID);
+    if (!ok) setValue(appGUID, QUuid::createUuid().toString() );
+
+    // By default sort RCS File preview by date, which is column 1
+    ok = contains(rcsFilePreviewSortColumn);
+    if (!ok) setRCSFilePreviewSortColumn(1);
+
     ok = contains(infoStyleSetpath);
     if (!ok) setValue(infoStyleSetpath,2);
 
@@ -200,6 +213,11 @@ void FWBSettings::init()
 #endif
 }
 
+QString FWBSettings::getAppGUID()
+{
+    return value(appGUID).toString();
+}
+
 QString FWBSettings::getStr(const QString &attribute)
 {
     QString path=SETTINGS_PATH_PREFIX "/"+attribute;
@@ -302,7 +320,6 @@ void FWBSettings::setSaveFileDir( const QString &d )
      setValue(sfdirSetpath,d);
 }
 
-
 void FWBSettings::save()
 {
     if (mw->db()!=NULL)
@@ -312,6 +329,26 @@ void FWBSettings::save()
 bool FWBSettings::getRCSLogState() { return value( emptyRCSLog ).toBool(); }
 void FWBSettings::setRCSLogState(bool f) { setValue( emptyRCSLog , f ); }
 
+int  FWBSettings::getRCSFilePreviewStyle()
+{
+    return value(rcsFilePreviewStyle).toInt();
+}
+
+void FWBSettings::setRCSFilePreviewStyle(int style)
+{
+    setValue(rcsFilePreviewStyle, style);
+}
+
+int  FWBSettings::getRCSFilePreviewSortColumn()
+{
+    return value(rcsFilePreviewSortColumn).toInt();
+}
+
+void FWBSettings::setRCSFilePreviewSortColumn(int col)
+{
+    setValue(rcsFilePreviewSortColumn, col);
+}
+
 bool FWBSettings::getAutoSave() { return value( autoSave ).toBool(); }
 void FWBSettings::setAutoSave(bool f) { setValue( autoSave, f); }
 
