@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.h 743 2009-01-19 08:50:59Z vadim $
+  $Id: FWBSettings.h 971 2009-05-27 20:40:51Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -105,6 +105,12 @@ class FWBSettings : public QSettings {
     bool    getRCSLogState();
     void    setRCSLogState(bool f);
 
+    int     getRCSFilePreviewStyle();
+    void    setRCSFilePreviewStyle(int style);
+
+    int     getRCSFilePreviewSortColumn();
+    void    setRCSFilePreviewSortColumn(int col);
+
     bool    getAutoSave();
     void    setAutoSave(bool f);
 
@@ -149,6 +155,8 @@ class FWBSettings : public QSettings {
     void    getPrinterOptions(QPrinter *printer,int &pageWidth,int &pageHeight);
     void    setPrinterOptions(QPrinter *printer,int pageWidth,int pageHeight);
 
+    QString getAppGUID();
+
     enum IconSize getIconsInRulesSize();
     void setIconsInRulesSize(enum IconSize size);
 
