@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.h 778 2009-03-07 04:32:28Z vadim $
+  $Id: FWWindow.h 973 2009-05-29 16:15:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,8 @@
 #define  __FWWINDOW_H_
 
 #include <ui_FWBMainWindow_q.h>
+#include <ui_pagesetupdialog_q.h>
+
 #include "RCS.h"
 #include "ObjectEditor.h"
 #include "HttpGet.h"
@@ -69,6 +71,8 @@ class FWWindow : public QMainWindow {
 
     Q_OBJECT
 
+    Ui::pageSetupDialog_q *psd;
+        
     QMdiArea *m_space;
     QWidget *instd;
     HttpGet *current_version_http_getter;
@@ -185,6 +189,8 @@ public slots:
     virtual void checkForUpgrade(const QString&);
 
     virtual void projectWindowClosed();
+
+    void tableResolutionSettingChanged(int );
     
  public:
     Ui::FWBMainWindow_q *m_mainWindow;
@@ -287,6 +293,9 @@ public slots:
     
     libfwbuilder::FWObject*  getCurrentLib();
 
+    void insertObjectInTree(libfwbuilder::FWObject *parent,
+                            libfwbuilder::FWObject *obj);
+
     libfwbuilder::FWObject* createObject(const QString &objType,
                                           const QString &objName,
                                           libfwbuilder::FWObject *copyFrom=NULL);
