@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.cpp 774 2009-03-04 17:27:21Z vadim $
+  $Id: FirewallDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -76,6 +76,11 @@ FirewallDialog::FirewallDialog(ProjectPanel *project, QWidget *parent) :
     obj=NULL;
 }
 
+void FirewallDialog::getHelpName(QString *str)
+{
+    *str = "FirewallDialog";
+}
+
 void FirewallDialog::loadFWObject(FWObject *o)
 {
     obj=o;
