@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallInstaller.h 768 2009-02-20 06:49:12Z vadim $
+  $Id: FirewallInstaller.h 888 2009-05-06 16:42:42Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -71,7 +71,8 @@ protected:
 
     instDialog *inst_dlg;
     instConf *cnf;
-    // session is used when e run built-in installer
+    QProcess  proc;
+    // session is used when we run built-in installer
     SSHSession  *session;
     std::list<instJob> job_list;
     QString fwb_prompt;
@@ -79,6 +80,7 @@ protected:
     void runSSHSession(SSHSession *s, bool intermediate=false);
     QString getFullPath(const QString &file );
 
+    void executeInstallScript();
     
 public:
 
