@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.cpp 564 2008-10-03 14:40:31Z vadim $
+  $Id: GroupObjectDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -304,6 +304,11 @@ void GroupObjectDialog::addIcon(FWObject *o, bool ref)
     listView->addTopLevelItem(tree_item);
 }
 
+void GroupObjectDialog::getHelpName(QString *str)
+{
+    *str = "GroupObjectDialog";
+}
+
 void GroupObjectDialog::loadFWObject(FWObject *o)
 {
     obj=o;
