@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: Help.cpp 664 2008-11-23 22:25:45Z vadim $
+  $Id: Help.cpp 935 2009-05-16 00:27:55Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -48,21 +48,21 @@ Help::Help(QWidget *parent, const QString &help_file, const QString &title) :
     resize(500, 600);
     raise();
 
-    setText(getHelpFileContents(help_file));
+    QString contents;
+    getHelpFileContents(help_file, contents);
+    setText(contents);
 };
 
-
 void Help::scrollToAnchor(const QString &anchor)
 {
     m_dialog->textview->scrollToAnchor(anchor);
 }
 
-
-QString Help::getHelpFileContents(const QString &help_file)
+bool Help::getHelpFileContents(const QString &help_file, QString &contents)
 {
     QString locale = QLocale::system().name(); //"en_US";
 
-    QString res;
+    bool res = false;
     QFile f;
     QTextStream ts;
 
@@ -76,11 +76,12 @@ QString Help::getHelpFileContents(const QString &help_file)
     if (Help::getFile(help_file, locale, f) && f.open(QIODevice::ReadOnly ))
     {
         ts.setDevice(&f);
-        res = ts.readAll();
+        contents = ts.readAll();
         f.close();
+        res = true;
     } else
     {
-        res = QString("Help file %1 not found.").arg(f.fileName());
+        contents = QString("Help file %1 not found.").arg(f.fileName());
     }
     return res;
 }
