@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: Help.h 669 2008-11-24 23:49:39Z vadim $
+  $Id: Help.h 935 2009-05-16 00:27:55Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -44,7 +44,8 @@ public:
 
     void scrollToAnchor(const QString &anchor);
 
-    static QString getHelpFileContents(const QString &help_file);
+    static bool getHelpFileContents(const QString &help_file,
+                                    QString &contents);
     static bool getFile(const QString &help_file, const QString &locale,
                         QFile &file);
 
