@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: HttpGet.cpp 645 2008-11-12 04:31:23Z vadim $
+  $Id: HttpGet.cpp 779 2009-03-10 04:11:02Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -106,8 +106,8 @@ bool HttpGet::get(const QUrl &url)
     agent += locale;
     agent += QString("; b:%1; ").arg(BUILD_NUM);
 #ifdef ELC
-    if (registered) agent += "r";
-    else            agent += "u";
+    if (registered==2) agent += "r";
+    else               agent += "u";
 #else
     agent += "u";
 #endif
