@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMPServiceDialog.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: ICMPServiceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -63,6 +63,11 @@ ICMPServiceDialog::~ICMPServiceDialog()
     delete m_dialog;
 }
 
+void ICMPServiceDialog::getHelpName(QString *str)
+{
+    *str = "ICMPServiceDialog";
+}
+
 void ICMPServiceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
