@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPServiceDialog.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: IPServiceDialog.cpp 1037 2009-06-05 16:58:28Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -76,6 +76,11 @@ void IPServiceDialog::setCodeLabel()
     }
 }
 
+void IPServiceDialog::getHelpName(QString *str)
+{
+    *str = "IPServiceDialog";
+}
+
 void IPServiceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
@@ -86,9 +91,9 @@ void IPServiceDialog::loadFWObject(FWObject *o)
 
     m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
     m_dialog->protocolNum->setValue( s->getProtocolNumber() );
-    m_dialog->lsrr->setChecked( s->getBool("m_dialog->lsrr") );
-    m_dialog->ssrr->setChecked( s->getBool("m_dialog->ssrr") );
-    m_dialog->rr->setChecked( s->getBool("m_dialog->rr") );
+    m_dialog->lsrr->setChecked( s->getBool("lsrr") );
+    m_dialog->ssrr->setChecked( s->getBool("ssrr") );
+    m_dialog->rr->setChecked( s->getBool("rr") );
     m_dialog->timestamp->setChecked( s->getBool("ts") );
     m_dialog->all_fragments->setChecked( s->getBool("fragm") );
     m_dialog->short_fragments->setChecked( s->getBool("short_fragm") );
