@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4Dialog.cpp 747 2009-01-23 21:37:12Z vadim $
+  $Id: IPv4Dialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -68,6 +68,11 @@ IPv4Dialog::~IPv4Dialog()
     delete m_dialog;
 }
 
+void IPv4Dialog::getHelpName(QString *str)
+{
+    *str = "IPv4Dialog";
+}
+
 void IPv4Dialog::loadFWObject(FWObject *o)
 {
     obj=o;
