@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibExportDialog.h,v 1.5 2006/07/13 04:59:22 vkurland Exp $
+  $Id: LibExportDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,9 +27,9 @@
 #ifndef __LIBEXPORTDIALOG_H_
 #define __LIBEXPORTDIALOG_H_
 
-#include "libexport_q.h"
+#include <ui_libexport_q.h>
 
-#include <qlistview.h>
+#include <QDialog>
 
 
 
@@ -43,17 +43,19 @@ namespace libfwbuilder {
     class FWReference;
 };
 
-class LibExportDialog : public  LibExport_q{
+class LibExportDialog : public  QDialog{
 
     Q_OBJECT
 
-
     void init();
 
 
  public:
     std::map<int, libfwbuilder::FWObject*>   mapOfLibs;
     LibExportDialog(QWidget* parent=0, const char* name=0, bool modal = FALSE );
+    ~LibExportDialog();
+    
+    Ui::LibExport_q *m_dialog;
  protected slots:
 
 };
