@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibraryDialog.cpp 418 2008-07-27 01:34:07Z vadim $
+  $Id: LibraryDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -70,6 +70,11 @@ LibraryDialog::~LibraryDialog()
     delete m_dialog;
 }
 
+void LibraryDialog::getHelpName(QString *str)
+{
+    *str = "LibraryDialog";
+}
+
 void LibraryDialog::loadFWObject(FWObject *o)
 {
     obj=o;
