@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NetworkDialogIPv6.cpp 747 2009-01-23 21:37:12Z vadim $
+  $Id: NetworkDialogIPv6.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -60,6 +60,11 @@ NetworkDialogIPv6::NetworkDialogIPv6(ProjectPanel *project, QWidget *parent) : Q
 
 NetworkDialogIPv6::~NetworkDialogIPv6() { delete m_dialog; }
 
+void NetworkDialogIPv6::getHelpName(QString *str)
+{
+    *str = "NetworkDialogIPv6";
+}
+
 void NetworkDialogIPv6::loadFWObject(FWObject *o)
 {
     obj=o;
