@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.h 685 2008-12-07 08:08:21Z vadim $
+  $Id: ObjectManipulator.h 973 2009-05-29 16:15:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -104,8 +104,8 @@ class ObjectManipulator : public QWidget/*ObjectManipulator_q*/ {
 
     int dedup_marker_global_counter;
     
-    ObjectTreeViewItem* insertObject( ObjectTreeViewItem *itm,
-                                      libfwbuilder::FWObject *obj );
+    ObjectTreeViewItem* insertObject(ObjectTreeViewItem *itm,
+                                     libfwbuilder::FWObject *obj);
     void insertSubtree( ObjectTreeViewItem *itm,libfwbuilder::FWObject *obj );
 
     void removeObjectFromTreeView(libfwbuilder::FWObject *obj );
@@ -122,23 +122,26 @@ class ObjectManipulator : public QWidget/*ObjectManipulator_q*/ {
     void updateCreateObjectMenu(libfwbuilder::FWObject* lib);
     void makeNameUnique(libfwbuilder::FWObject* p,libfwbuilder::FWObject* obj);
 
-    libfwbuilder::FWObject* actuallyCreateObject(libfwbuilder::FWObject *parent,
-                                                 const QString &objType,
-                                                 const QString &objName,
-                                                 libfwbuilder::FWObject *copyFrom=NULL);
+    libfwbuilder::FWObject* actuallyCreateObject(
+        libfwbuilder::FWObject *parent,
+        const QString &objType,
+        const QString &objName,
+        libfwbuilder::FWObject *copyFrom=NULL);
 
     void autorename(libfwbuilder::FWObject *obj,bool ask=true);
-    void extractFirewallsFromGroup(
-            libfwbuilder::ObjectGroup *gr,
-            std::set<libfwbuilder::Firewall*> &fo);
-
-     libfwbuilder::FWObject* actuallyPasteTo(libfwbuilder::FWObject *target,
-                                             libfwbuilder::FWObject *obj,
-                                             std::map<int,int> &map_ids);
-
-     bool validateForPaste(libfwbuilder::FWObject *target,
-                           libfwbuilder::FWObject *obj);
+    void extractFirewallsFromGroup(libfwbuilder::ObjectGroup *gr,
+                                   std::set<libfwbuilder::Firewall*> &fo);
+    
+    libfwbuilder::FWObject* actuallyPasteTo(libfwbuilder::FWObject *target,
+                                            libfwbuilder::FWObject *obj,
+                                            std::map<int,int> &map_ids);
 
+    bool validateForPaste(libfwbuilder::FWObject *target,
+                          libfwbuilder::FWObject *obj);
+    
+    void findWhereUsedRecursively(libfwbuilder::FWObject *obj,
+                                  libfwbuilder::FWObject *top,
+                                  std::set<libfwbuilder::FWObject*> &resset);
     
 public slots:
      virtual void libChanged(int l);
@@ -263,6 +266,9 @@ public:
 
      void reopenCurrentItemParent();
 
+     void insertObjectInTree(libfwbuilder::FWObject *parent,
+                             libfwbuilder::FWObject *obj);
+
      void openObject(libfwbuilder::FWObject *obj, bool register_in_history);
      void openObject(ObjectTreeViewItem *otvi,    bool register_in_history);
 
