@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.cpp 607 2008-10-11 22:34:19Z vadim $
+  $Id: ObjectTreeView.cpp 986 2009-05-31 21:22:59Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -344,6 +344,8 @@ void ObjectTreeView::updateTreeItems()
 void ObjectTreeView::startDrag(Qt::DropActions supportedActions)
 {
     QTreeWidgetItem *ovi = currentItem();
+    if (ovi==NULL) return;
+
     ObjectTreeViewItem *otvi=dynamic_cast<ObjectTreeViewItem*>(ovi);
 
     FWObject *current_obj = getCurrentObject();
@@ -489,15 +491,24 @@ bool ObjectTreeView::isCurrReadOnly(QDragMoveEvent *ev)
 
 void ObjectTreeView::dragMoveEvent( QDragMoveEvent *ev)
 {
+    QWidget *fromWidget = ev->source();
+
+    // The source of DnD object must be the same instance of fwbuilder
+    if (!fromWidget)
+    {
+        ev->setAccepted(false);
+        return;
+    }
+   
     if (isCurrReadOnly(ev) ||
-          !ev->mimeData()->hasFormat(FWObjectDrag::FWB_MIME_TYPE))
+        !ev->mimeData()->hasFormat(FWObjectDrag::FWB_MIME_TYPE))
     {
         ev->setAccepted(false);
         return;
     }
     list<FWObject*> dragol;
     if (!FWObjectDrag::decode(ev, dragol))
-       ev->setAccepted(false);
+        ev->setAccepted(false);
     for (list<FWObject*>::iterator i=dragol.begin();i!=dragol.end(); ++i)
     {
         FWObject *dragobj = *i;
@@ -510,13 +521,22 @@ void ObjectTreeView::dragMoveEvent( QDragMoveEvent *ev)
             return;
         }
     }
+
     ev->setAccepted(true);
 }
 
 void ObjectTreeView::dropEvent(QDropEvent *ev)
 {
     if (fwbdebug) qDebug("ObjectTreeView::dropEvent");
+    QWidget *fromWidget = ev->source();
 
+    // The source of DnD object must be the same instance of fwbuilder
+    if (!fromWidget)
+    {
+        ev->setAccepted(false);
+        return;
+    }
+   
     list<FWObject*> dragol;
     if (FWObjectDrag::decode(ev, dragol))
     {
