@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.h,v 1.22 2007/01/08 03:37:53 vkurland Exp $
+  $Id: ObjectTreeView.h 521 2008-09-10 06:15:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,60 +27,84 @@
 #ifndef  __OBJECTTREEVIEW_H_
 #define  __OBJECTTREEVIEW_H_
 
-#include <qlistview.h>
-#include <qdragobject.h>
-#include <qiconview.h>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
+#include <QMimeData>
 #include <qtimer.h>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QMouseEvent>
+#include <QDragMoveEvent>
+#include <QKeyEvent>
+#include <QFocusEvent>
+#include <QDragLeaveEvent>
 
 #include <vector>
+#include <set>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class ObjectTreeView : public QListView {
+class ProjectPanel;
+
+class ObjectTreeView : public QTreeWidget {
 
      Q_OBJECT
 
-    QListViewItem   *item_before_drag_started;
-    QListViewItem   *lastSelected;
-    QTimer           singleClickTimer;
-    bool             second_click;
+    QTreeWidgetItem *item_before_drag_started;
+    QTreeWidgetItem *lastSelected;
+    QItemSelection lastSelection;
+    bool second_click;
+    bool selectionFrozen;
+    bool expandOrCollapse;
+    bool Lockable;
+    bool Unlockable;
+    bool startingDrag;
+    bool visible;
+    bool process_mouse_release_event;
+    std::set<int> expanded_objects;
+    std::vector<libfwbuilder::FWObject*> selectedObjects;
+    ProjectPanel* m_project;
 
-    bool             selectionFrozen;
-    bool             expandOrCollapse;
-    bool             Lockable;
-    bool             Unlockable;
 
-    bool             visible;
+    bool isCurrReadOnly(QDragMoveEvent *ev);
+    libfwbuilder::FWObject *getDropTarget(
+        QDropEvent *ev, libfwbuilder::FWObject* dragobj);
 
-    bool             process_mouse_release_event;
+protected:
 
-    std::vector<libfwbuilder::FWObject*>          selectedObjects;
-        
- protected:
+    bool event( QEvent *event );
 
     virtual void dragEnterEvent( QDragEnterEvent *ev);
     virtual void dragMoveEvent( QDragMoveEvent *ev);
     virtual void dropEvent(QDropEvent *ev);
-    virtual QDragObject* dragObject();
     virtual void dragLeaveEvent( QDragLeaveEvent *ev);
 
-    virtual void contentsMousePressEvent( QMouseEvent *e );
-    virtual void contentsMouseReleaseEvent( QMouseEvent *e );
-    virtual void contentsMouseDoubleClickEvent( QMouseEvent *e );
-    virtual void contentsMouseMoveEvent( QMouseEvent *e );
     virtual void keyPressEvent( QKeyEvent* ev );
+    virtual void mousePressEvent( QMouseEvent *e );
+    virtual void mouseReleaseEvent( QMouseEvent *e );
+    //virtual void mouseDoubleClickEvent( QMouseEvent *e );
+    virtual void mouseMoveEvent( QMouseEvent *e );
+
     virtual void keyReleaseEvent( QKeyEvent* ev );
 
     virtual void focusInEvent(QFocusEvent*);
     virtual void focusOutEvent(QFocusEvent*);
+
+    virtual bool edit(const QModelIndex &index,
+                      EditTrigger trigger, QEvent *event);
+    
+    void startDrag(Qt::DropActions supportedActions);
     
  public:
 
-    ObjectTreeView(QWidget* parent = 0, const char * name = 0, WFlags f = 0);
+    ObjectTreeView(ProjectPanel* project,
+                   QWidget* parent = 0,
+                   const char * name = 0,
+                   Qt::WFlags f = 0);
 
-    void freezeSelection(bool f) { selectionFrozen=f; }
+    void freezeSelection(bool f) { selectionFrozen = f; }
 
     std::vector<libfwbuilder::FWObject*>& getSelectedObjects()
         { return selectedObjects; }
@@ -99,7 +123,7 @@ class ObjectTreeView : public QListView {
 
     void becomingVisible() { visible=true; }
     void becomingHidden()  { visible=false; }
-
+    void updateAfterPrefEdit();
 /* Under some circumstances, user may select several host or fw
  * objects so that their children objects are selected as well
  * (e.g. when shift-click is used). "Delete objects" or "group
@@ -112,16 +136,19 @@ class ObjectTreeView : public QListView {
     std::vector<libfwbuilder::FWObject*> getSimplifiedSelection();
 
     void ignoreNextMouseReleaseEvent() { process_mouse_release_event = false; }
-    
+
+    void ExpandTreeItems(const std::set<int> &ids);
+    const std::set<int>& getListOfExpandedObjectIds() { return expanded_objects; }
+
  public slots:
 
-     void selectionChanged();
-     void resetSelection();
-     void returnPressed(QListViewItem *itm);
-     void currentChanged(QListViewItem *itm);
-     void collapsed(QListViewItem *itm);
-     void expanded(QListViewItem *itm);
-     virtual void updateTreeItems();
+    void itemSelectionChanged();
+    void resetSelection();
+    void currentItemChanged(QTreeWidgetItem *cur);
+    void itemCollapsed(QTreeWidgetItem *itm);
+    void itemExpanded(QTreeWidgetItem *itm);
+    void itemOpened ();
+    virtual void updateTreeItems();
 
  signals:
 
@@ -130,6 +157,7 @@ class ObjectTreeView : public QListView {
      void switchObjectInEditor_sign(libfwbuilder::FWObject*);
      void objectDropped_sign(libfwbuilder::FWObject *);
      void deleteObject_sign(libfwbuilder::FWObject *);
+     void contextMenuRequested_sign(const QPoint&);
 };
 
 
