@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PhysicalAddressDialog.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: PhysicalAddressDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -64,6 +64,11 @@ PhysicalAddressDialog::~PhysicalAddressDialog()
     delete m_dialog;
 }
 
+void PhysicalAddressDialog::getHelpName(QString *str)
+{
+    *str = "PhysicalAddressDialog";
+}
+
 void PhysicalAddressDialog::loadFWObject(FWObject *o)
 {
     obj=o;
