@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrefsDialog.cpp 968 2009-05-27 06:03:41Z vadim $
+  $Id: PrefsDialog.cpp 1474 2009-09-18 17:22:54Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -404,18 +404,22 @@ void PrefsDialog::checkForUpgrade(const QString& server_response)
 
     if (current_version_http_getter.getStatus())
     {
-
-        if (server_response.trimmed().isEmpty())
-        {
-            QMessageBox::information(
-                this,"Firewall Builder",
-                tr("Your version of Firewall Builder is up to date."));
-        } else
+        /*
+         * server response may be some html or other data in case
+         * connection goes via proxy, esp. with captive portals. We
+         * should not interpret that as "new version is available"
+         */
+        if (server_response.trimmed() == "update = 1")
         {
             QMessageBox::warning(
                 this,"Firewall Builder",
                 tr("A new version of Firewall Builder is available at"
                    " http://www.fwbuilder.org"));
+        } else
+        {
+            QMessageBox::information(
+                this,"Firewall Builder",
+                tr("Your version of Firewall Builder is up to date."));
         }
     } else
     {
