@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel.cpp 778 2009-03-07 04:32:28Z vadim $
+  $Id: ProjectPanel.cpp 973 2009-05-29 16:15:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -114,6 +114,7 @@ void ProjectPanel::initMain(FWWindow *main)
     oe  = new ObjectEditor((QWidget*)m_panel->objectEditorStack, this);
     oe->setCloseButton(m_panel->closeObjectEditorButton);
     oe->setApplyButton(m_panel->applyObjectEditorButton);
+    oe->setHelpButton(m_panel->helpObjectEditorButton);
     closeEditorPanel();
     oe->hide();
 
@@ -622,6 +623,11 @@ void ProjectPanel::loadDataFromFw(Firewall *fw)
     }
 }
 
+void ProjectPanel::insertObjectInTree(FWObject *parent, FWObject *obj)
+{
+    m_panel->om->insertObjectInTree(parent, obj);
+}
+
 FWObject* ProjectPanel::createObject(const QString &objType,
                                      const QString &objName,
                                      FWObject *copyFrom)
@@ -1193,6 +1199,9 @@ bool ProjectPanel::validateForInsertion(FWObject *target, FWObject *obj)
     return objectTreeFormat->validateForInsertion(target, obj);
 }
 
+/*
+ * TODO: move get*MenuState methods to ObjectManipulator
+ */
 bool ProjectPanel::getCopyMenuState(const QString &objPath)
 {
     return objectTreeFormat->getCopyMenuState(objPath);
