@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel_file_ops.cpp 743 2009-01-19 08:50:59Z vadim $
+  $Id: ProjectPanel_file_ops.cpp 958 2009-05-21 17:55:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -172,12 +172,30 @@ bool ProjectPanel::fileOpen()
  * hidden ProjectPanel object. This is the only difference I can think
  * of.
  */
-    QMdiSubWindow *current_active_window=mainW->getMdiArea()->activeSubWindow();
+    QMdiSubWindow *current_active_window = mainW->getMdiArea()->activeSubWindow();
 
     QString dir;
-    dir=st->getWDir();
-    if (dir.isEmpty())  dir=st->getOpenFileDir();
-    if (dir.isEmpty())  dir=userDataDir.c_str();
+
+/*
+ * Pick default directory where to look for the file to open.
+ * 1) if "work directory" is configured in preferences, always use it
+ * 2) if it is blank, use the same directory where currently opened file is
+ * 3) if this is the first file to be opened, get directory where the user opened
+ *    during last session from settings using st->getOpenFileDir
+ */
+
+    dir = st->getWDir();
+    if (fwbdebug) qDebug("Choosing directory for file open 1: %s",
+                         dir.toStdString().c_str());
+
+    if (dir.isEmpty() && !mw->getCurrentFileName().isEmpty())
+        dir = getFileDir(mw->getCurrentFileName());
+    if (fwbdebug) qDebug("Choosing directory for file open 2: %s",
+                         dir.toStdString().c_str());
+
+    if (dir.isEmpty()) dir = st->getOpenFileDir();
+    if (fwbdebug) qDebug("Choosing directory for file open 3: %s",
+                         dir.toStdString().c_str());
 
     QString fileName = QFileDialog::getOpenFileName(
         mainW,
@@ -193,6 +211,7 @@ bool ProjectPanel::fileOpen()
 
     bool res = loadFile(fileName, false);
     if (res) mw->updateOpenRecentMenu(fileName);
+
     return res;
 }
 
@@ -241,6 +260,8 @@ bool ProjectPanel::loadFile(const QString &fileName, bool load_rcs_head)
     if (new_rcs->isTemp())
         unlink(new_rcs->getFileName().toLocal8Bit().constData());
 
+    st->setOpenFileDir(getFileDir(fileName));
+
     return true;
 }
 
