@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrototypeDialogClass.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: PrototypeDialogClass.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -44,6 +44,11 @@
 using namespace libfwbuilder;
 using namespace std;
 
+void PrototypeDialog::getHelpName(QString *str)
+{
+    *str = "PrototypeDialog";
+}
+
 void PrototypeDialog::loadFWObject(FWObject *o)
 {
     obj=o;
