@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.cpp 634 2008-10-25 18:56:14Z vadim $
+  $Id: RCS.cpp 686 2008-12-08 17:13:50Z svn $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -362,6 +362,7 @@ RCS::RCS(const QString &file)
                 r.log += log_rx.cap(1);
 
             r.log.replace('\r',"");
+            
 
             if (r.rev != "")
             {
@@ -920,9 +921,9 @@ QString RCS::rlog() throw(libfwbuilder::FWException)
     proc->waitForFinished();
 
     if (fwbdebug) qDebug("Running rlog: finished reading");
-
-    QString rlogTxt = QString::fromLocal8Bit(
-        stdoutBuffer.toAscii().constData());
+    // Note: we convert rlog comments to Utf8. Local8Bit does not seem
+    // to work on windows, produces '????'
+    QString rlogTxt = QString::fromUtf8(stdoutBuffer.toAscii().constData());
 
     if (proc->state() == QProcess::NotRunning && proc->exitCode()==0)
         return rlogTxt;
