@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp 342 2008-07-07 22:37:45Z vadim $
+  $Id: RuleOptionsDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -69,6 +69,12 @@ RuleOptionsDialog::RuleOptionsDialog(ProjectPanel *project, QWidget *parent) : Q
     init=false;
 }
 
+void RuleOptionsDialog::getHelpName(QString *str)
+{
+    // can make help name different depending on the currently opened tab
+    *str = help_name;
+}
+
 void RuleOptionsDialog::loadFWObject(FWObject *o)
 {
     obj=o;
@@ -78,6 +84,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     while ( !Firewall::isA(p) ) p=p->getParent();
     platform=p->getStr("platform").c_str();
 
+    help_name = platform + "_rule_options";
 
     Rule      *rule = dynamic_cast<Rule*>(o);
     FWOptions *ropt = rule->getOptionsObject();
@@ -176,9 +183,14 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
 
     if (platform=="pf")
     {
-        data.registerOption(m_dialog->pf_logPrefix, ropt,  "log_prefix");
-        data.registerOption(m_dialog->pf_stateless, ropt,  "stateless");
-        data.registerOption(m_dialog->pf_keep_state, ropt,  "pf_keep_state");
+        data.registerOption(m_dialog->pf_logPrefix, ropt,
+                            "log_prefix");
+        data.registerOption(m_dialog->pf_stateless, ropt,
+                            "stateless");
+        data.registerOption(m_dialog->pf_keep_state, ropt,
+                            "pf_keep_state");
+        data.registerOption(m_dialog->pf_sloppy_tracker, ropt,
+                            "pf_sloppy_tracker");
         data.registerOption(m_dialog->pf_rule_max_state, ropt,
                             "pf_rule_max_state");
         data.registerOption(m_dialog->pf_source_tracking, ropt,
@@ -187,7 +199,6 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
                             "pf_max_src_nodes");
         data.registerOption(m_dialog->pf_max_src_states, ropt,
                             "pf_max_src_states");
-
         data.registerOption(m_dialog->pf_max_src_conn, ropt,
                             "pf_max_src_conn");
         data.registerOption(m_dialog->pf_overload_table, ropt,
@@ -196,12 +207,10 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
                             "pf_max_src_conn_flush");
         data.registerOption(m_dialog->pf_global, ropt,
                             "pf_max_src_conn_global");
-
         data.registerOption(m_dialog->pf_max_src_conn_rate_num, ropt,
                              "pf_max_src_conn_rate_num");
         data.registerOption(m_dialog->pf_max_src_conn_rate_seconds, ropt,
                              "pf_max_src_conn_rate_seconds");
-
         data.registerOption(m_dialog->pf_modulate, ropt,
                              "pf_modulate_state");
         data.registerOption(m_dialog->pf_synproxy, ropt,
