@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleSetView.h 635 2008-10-26 23:27:08Z vadim $
+  $Id: RuleSetView.h 732 2009-01-02 08:26:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -343,7 +343,8 @@ public:
     bool supports_time;
     bool supports_logging;
     bool supports_rule_options;
- 
+    bool supports_routing_itf;
+    
     int RuleElementSpacing;
 
     int pixmap_h;
@@ -530,7 +531,6 @@ class PolicyView : public RuleSetView
     virtual ~PolicyView() {}
 
     virtual void init();
-    
 };
 
 class NATView : public RuleSetView
@@ -544,8 +544,6 @@ class NATView : public RuleSetView
     virtual ~NATView() {}
 
     virtual void init();
-    
-
 };
 
 class RoutingView : public RuleSetView
@@ -560,7 +558,12 @@ class RoutingView : public RuleSetView
     virtual ~RoutingView() {}
 
     virtual void init();
-    
-
 };
 
+class RuleSetViewFactory
+{
+public:
+    static RuleSetView* getRuleSetViewByType(ProjectPanel *project,
+                                             libfwbuilder::RuleSet *ruleset,
+                                             QWidget *parent);
+};
