@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.h 304 2008-07-03 02:19:16Z vadim $
+  $Id: SSHPIX.h 585 2008-10-09 05:08:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,12 +38,13 @@
 #include <list>
 #include <string>
 
-
+class QEventLoop;
 
 class SSHPIX : public SSHSession {
 
     Q_OBJECT
 
+    QEventLoop *local_event_loop;
     int         nLines;
     int         ncmd;
     QStringList allConfig;
