@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.h 469 2008-08-15 05:49:30Z vadim $
+  $Id: SSHSession.h 769 2009-02-21 22:42:38Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -67,6 +67,7 @@ class SSHSession : public QObject {
     bool       enable;
     bool       configure;
     bool       endOfCopy;
+    bool       send_keepalive;
     
     enum State { NONE,
                  LOGGEDIN,
@@ -124,7 +125,8 @@ class SSHSession : public QObject {
     QString     ssoft_prompt1;
     QString     ssoft_prompt2;
     QString     ssoft_config_prompt;
-    QString     sudo_pwd_prompt;
+    QString     sudo_pwd_prompt_1;
+    QString     sudo_pwd_prompt_2;
     QString     passphrase_prompt;
     QString     epwd_prompt;
     
