@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.cpp 469 2008-08-15 05:49:30Z vadim $
+  $Id: SSHUnx.cpp 769 2009-02-21 22:42:38Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -56,7 +56,8 @@ SSHUnx::SSHUnx(QWidget *_par,
     epwd_prompt="Password: ";
     ssh_pwd_prompt="'s password: ";
     ssoft_config_prompt="> ";
-    sudo_pwd_prompt="Password:";
+    sudo_pwd_prompt_1="Password:";
+    sudo_pwd_prompt_2="[sudo] password for ";
     putty_pwd_prompt="Password: ";
     passphrase_prompt="Enter passphrase for key ";
 
@@ -88,10 +89,10 @@ bool SSHUnx::checkForErrors(QStringList *errptr)
 
     for (QStringList::const_iterator i=errptr->begin(); i!=errptr->end(); ++i)
     {
-        if (fwbdebug)
-            qDebug(
-                QString("SSHUnx::stateMachine:  error='%1'").
-                arg(*i).toAscii().constData());
+        // if (fwbdebug)
+        //     qDebug(
+        //         QString("SSHUnx::stateMachine:  error='%1'").
+        //         arg(*i).toAscii().constData());
 
         if ( stdoutBuffer.lastIndexOf(QRegExp(*i),-1)!=-1 )
         {
@@ -142,27 +143,31 @@ void SSHUnx::stateMachine()
              cmpPrompt(stdoutBuffer, putty_pwd_prompt) ||
              cmpPrompt(stdoutBuffer, thinkfinger_pwd_prompt) ||
              stdoutBuffer.lastIndexOf(passphrase_prompt, -1)!=-1 ||
-
-             cmpPrompt(stdoutBuffer, sudo_pwd_prompt) ||
-             cmpPrompt(stderrBuffer, sudo_pwd_prompt) )
+             cmpPrompt(stdoutBuffer, sudo_pwd_prompt_1) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt_1) ||
+             cmpPrompt(stdoutBuffer, sudo_pwd_prompt_2) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt_2)
+        )
         {
             stdoutBuffer="";
             proc->write( pwd.toAscii() );
             proc->write( "\n" );
             break;
         }
-/* we may get to LOGGEDIN state directly from NONE, for example when
- * password is supplied on command line to plink.exe
- */
+        // we may get to LOGGEDIN state directly from NONE, for
+        // example when password is supplied on command line to
+        // plink.exe
         if (cmpPrompt(stdoutBuffer,normal_prompt) ||
             cmpPrompt(stdoutBuffer,fwb_prompt))
         {
-            state=PUSHING_CONFIG;
+            state = PUSHING_CONFIG;
+            // start sending keepalive chars (just "\n", done in
+            // SSHSession::heartBeat()) to keep session alive and to
+            // force firewall to restore session state after policy
+            // has been reloaded  and state possibly purged.
+            send_keepalive = true;
             if (!quiet) emit printStdout_sign( tr("Logged in") + "\n" );
-            if (fwbdebug)
-                qDebug("SSHUnx::stateMachine logged in");
-//            proc->write( "\n" );
-//            stdoutBuffer="";
+            if (fwbdebug) qDebug("SSHUnx::stateMachine logged in");
             goto push_files;
         }
 
@@ -214,8 +219,11 @@ void SSHUnx::stateMachine()
 /* in this state we may need to enter sudo password */
     case PUSHING_CONFIG:
  push_files:
-        if ( cmpPrompt(stdoutBuffer, sudo_pwd_prompt) ||
-             cmpPrompt(stderrBuffer, sudo_pwd_prompt) )
+        if ( cmpPrompt(stdoutBuffer, sudo_pwd_prompt_1) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt_1) ||
+             cmpPrompt(stdoutBuffer, sudo_pwd_prompt_2) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt_2)
+        )
         {
             stdoutBuffer="";
             proc->write( pwd.toAscii() );
@@ -242,7 +250,8 @@ void SSHUnx::stateMachine()
 
 /* we get to this state when previous ssh or scp command terminates */
     case FINISH:
-        if ( (proc->state()==QProcess::NotRunning) && (proc->exitStatus()==QProcess::NormalExit))
+        if ( (proc->state()==QProcess::NotRunning) &&
+             (proc->exitStatus()==QProcess::NormalExit))
         {
             emit printStdout_sign( "\n");
             emit printStdout_sign( tr("Done") );
