@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SimpleTextEditor.h,v 1.4 2007/01/06 22:03:25 vkurland Exp $
+  $Id: SimpleTextEditor.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,19 +26,21 @@
 #ifndef __SIMPLETEXTEDITOR_H__
 #define __SIMPLETEXTEDITOR_H__
 
-#include "config.h"
-#include "simpletexteditor_q.h"
+#include "../../config.h"
+#include <ui_simpletexteditor_q.h>
 
-class SimpleTextEditor : public SimpleTextEditor_q
+class SimpleTextEditor : public QDialog
 {
     Q_OBJECT
 
  public:
-
+    Ui::SimpleTextEditor_q *m_dialog;
+    
     SimpleTextEditor(QWidget *parent,
                      const QString &txt,
                      bool enableLoadFromFile=true,
                      const QString &title="");
+    ~SimpleTextEditor();
 
     QString text();
 
