@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: StartTipDialog.h 660 2008-11-23 03:19:04Z vadim $
+  $Id: StartTipDialog.h 935 2009-05-16 00:27:55Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,12 +30,28 @@
 #include "../../config.h"
 
 #include "ui_starttipdialog_q.h"
+#include "HttpGet.h"
+
+#include <QStringList>
+#include <QString>
 #include <QDialog>
 
+#include <time.h>
+
 class StartTipDialog : public QDialog
 {
     Q_OBJECT
 
+    HttpGet *http_getter;
+    QStringList tips;
+    int current_tip;
+    time_t start_time;
+    bool first_run;
+    
+    void showTip(const QString &txt, bool new_tip=true);
+    void showTip(int tip_idx);
+    QString getRandomTip();
+
 public:
     Ui::StartTipDialog_q *m_dialog;
 
@@ -43,7 +59,12 @@ public:
     
     virtual ~StartTipDialog() {};
 
+    void run();
+
 public slots:
+    void downloadComplete(const QString&);
+    void nextTip();
+    void prevTip();
     virtual void close();
 };
 
