@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TimeDialog.cpp 537 2008-09-14 17:12:05Z vadim $
+  $Id: TimeDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -65,6 +65,11 @@ TimeDialog::~TimeDialog()
     delete m_dialog;
 }
 
+void TimeDialog::getHelpName(QString *str)
+{
+    *str = "TimeDialog";
+}
+
 void TimeDialog::loadFWObject(FWObject *o)
 {
     obj=o;
