@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: UDPServiceDialog.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: UDPServiceDialog.cpp 952 2009-05-20 21:54:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -61,6 +61,11 @@ UDPServiceDialog::~UDPServiceDialog()
     delete m_dialog;
 }
 
+void UDPServiceDialog::getHelpName(QString *str)
+{
+    *str = "UDPServiceDialog";
+}
+
 void UDPServiceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
