@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: check_update_url.h 650 2008-11-18 16:12:03Z vadim $
+  $Id: check_update_url.h 968 2009-05-27 06:03:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,10 +27,7 @@
 #ifndef CHECK_UPDATE_URL_HH
 #define CHECK_UPDATE_URL_HH
 
-#include "../../VERSION.h"
-#include "../../build_num"
-
-#define CHECK_UPDATE_URL "http://update.fwbuilder.org/update_checks/check.cgi?v="VERSION
+#define CHECK_UPDATE_URL "http://update.fwbuilder.org/update_checks/check.cgi?v=%1&uuid=%2"
 
 #endif
 
