@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: execDialog.h,v 1.4 2006/02/18 05:26:30 vkurland Exp $
+  $Id: execDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,23 +27,25 @@
 #ifndef __EXECDIALOG_H_
 #define __EXECDIALOG_H_
 
-#include "execdialog_q.h"
+#include <ui_execdialog_q.h>
 
-#include <qvaluelist.h>
+#include <qlist.h>
 #include <qstring.h>
 #include <qprocess.h>
 #include <qwidget.h>
 
-class execDialog : public execDialog_q
+class execDialog : public QDialog
 {
     Q_OBJECT
 
     QProcess proc;
     int      res;
+    Ui::execDialog_q *m_dialog;
+    QStringList arguments;
     
 public:
     execDialog(QWidget *parent,const QStringList &args, const QString &closeButtonText="");
-
+    ~execDialog();
     int run();
 
 public slots:
