@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: filePropDialog.cpp 540 2008-09-15 06:04:55Z vadim $
+  $Id: filePropDialog.cpp 653 2008-11-20 06:22:06Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -152,9 +152,9 @@ void filePropDialog::printRevHistory()
 	QString headerText = "Revision History:";
 
 #if defined(Q_OS_MACX)
-	printerStream pr(printer,margin,printHeader,headerText,NULL);
+	printerStream pr(printer,1.0,margin,printHeader,headerText,NULL);
 #else
-	printerStream pr(printer,margin,printHeader,headerText,ppd);
+	printerStream pr(printer,1.0,margin,printHeader,headerText,ppd);
 	ppd->show();
 #endif
 	pr.setFromTo(fromPage,toPage);
