@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: freebsdAdvancedDialog.h,v 1.1 2004/05/11 04:45:38 vkurland Exp $
+  $Id: freebsdAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,23 +27,26 @@
 #ifndef __FREEBSDADVANCEDDIALOG_H_
 #define __FREEBSDADVANCEDDIALOG_H_
 
-#include "freebsdadvanceddialog_q.h"
+#include <ui_freebsdadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class freebsdAdvancedDialog : public freebsdAdvancedDialog_q
+class freebsdAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::freebsdAdvancedDialog_q     *m_dialog;
 
  public:
     freebsdAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
-
+    ~freebsdAdvancedDialog();
+    
 protected slots:
 
     virtual void accept();
