@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instConf.h 304 2008-07-03 02:19:16Z vadim $
+  $Id: instConf.h 585 2008-10-09 05:08:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -63,6 +63,7 @@ class instConf {
     QString   epwd;
     QString   maddr;
     QString   sshArgs;
+    QString   scpArgs;
     QString   fwdir;
     int       rollbackTime;
     QString   rollbackTimeUnit;
@@ -77,7 +78,7 @@ class instConf {
     instConf();
 
     QString getCmdFromResource(const QString &resource_name);
-   
+    void clear();
    
 };
 
