@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp 888 2009-05-06 16:42:42Z vadim $
+  $Id: instDialog.cpp 1374 2009-08-31 20:33:22Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -105,6 +105,16 @@ instDialog::instDialog(QWidget* p,
     rejectDialogFlag = false;
 
     currentLog = m_dialog->procLogDisplay;
+    QTextCursor cursor(currentLog->textCursor());
+    normal_format = cursor.charFormat();
+    error_format = normal_format;
+    error_format.setForeground(QBrush(Qt::red));
+    // weight must be between 0 and 99. Qt 4.4.1 does not seem to mind if
+    // it is >99 (just caps it) but older versions assert
+    error_format.setProperty(QTextFormat::FontWeight, 99);
+    highlight_format = normal_format;
+    highlight_format.setProperty(QTextFormat::FontWeight, 99);
+
     currentSaveButton = m_dialog->saveMCLogButton;
     currentSaveButton->setEnabled(true);
     currentStopButton = m_dialog->controlMCButton;
