@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.h 888 2009-05-06 16:42:42Z vadim $
+  $Id: instDialog.h 1373 2009-08-31 18:58:37Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -55,6 +55,7 @@ class QCheckListItem;
 class QPushButton;
 class QProgressBar;
 class QStringList;
+class QTextCharFormat;
 //class QCheckTableItem;
 
 namespace libfwbuilder
@@ -116,6 +117,10 @@ class instDialog : public QDialog, public FakeWizard
     bool showSelectedFlag;
 
     QTextEdit *currentLog;
+    QTextCharFormat normal_format;
+    QTextCharFormat error_format;
+    QTextCharFormat highlight_format;
+    
     QPushButton *currentSaveButton;
     QPushButton *currentStopButton;
     QProgressBar *currentProgressBar;
