@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog_compile.cpp 717 2008-12-29 17:49:20Z vadim $
+  $Id: instDialog_compile.cpp 888 2009-05-06 16:42:42Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -109,24 +109,12 @@ bool instDialog::runCompiler(Firewall *fw)
     connect(currentStopButton, SIGNAL(clicked()),
             this, SLOT(stopCompile()));
 
-    proc.disconnect(SIGNAL(finished(int,QProcess::ExitStatus)));
-    connect(&proc, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(compilerFinished(int,QProcess::ExitStatus)) );
-
-    proc.start(path, args);
-
     currentStopButton->setText(tr("Stop"));
     currentStopButton->setEnabled(true);
 
-    if ( !proc.waitForStarted() )
-    {
-        opError(cnf.fwobj);
-        addToLog( tr("Error: Failed to start program") );
-        blockInstallForFirewall(cnf.fwobj);
+    setUpProcessToCompile();
+    if (!executeCommand(path, args))
         QTimer::singleShot( 0, this, SLOT(mainLoopCompile()));
-        return false;
-    }
-    args.push_front(path);
 
     return true;
 }
