@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog_installer.cpp 730 2009-01-02 00:53:35Z vadim $
+  $Id: instDialog_installer.cpp 888 2009-05-06 16:42:42Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -169,7 +169,13 @@ void instDialog::installerFinished(int ret_code, QProcess::ExitStatus status)
     if( fwbdebug) qDebug("instDialog::installerFinished "
                          "exit code = %d exit_status=%d",
                          ret_code, status);
-
+    // run readFromStdout() and processEvents() to make sure all
+    // events that pass output from the external installer script have
+    // been processed. Otherwise the output from the next installer
+    // pass in batch install mixes with the tail of the output from
+    // the previous one.
+    readFromStdout();
+    qApp->processEvents();
     if (ret_code==0 && status==QProcess::NormalExit)
         installerSuccess();
     else
