@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instOptionsDialog.h,v 1.4 2007/05/11 02:14:30 vkurland Exp $
+  $Id: instOptionsDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,24 +27,27 @@
 #ifndef __INSTOPTIONSDIALOG_H_
 #define __INSTOPTIONSDIALOG_H_
 
-#include "config.h"
-#include <instoptionsdialog_q.h>
+#include "../../config.h"
+#include <ui_instoptionsdialog_q.h>
 
 class instConf;
 
-class instOptionsDialog : public instOptionsDialog_q
+class instOptionsDialog : public QDialog
 {
     Q_OBJECT
  private:
     int delta_y;
     instConf *cnf;
-    
+
  public:
     instOptionsDialog(QWidget *parent, instConf *_cnf);
+    ~instOptionsDialog();
 
     QString getUName();
     QString getPWD();
     QString getEPWD();
+    
+    Ui::instOptionsDialog_q *m_dialog;
 
  public slots:
     
