@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iosaclAdvancedDialog.cpp 761 2009-02-14 01:57:41Z vadim $
+  $Id: iosaclAdvancedDialog.cpp 1051 2009-06-11 20:17:10Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -258,6 +258,9 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->iosacl_include_comments, fwoptions,
                          "iosacl_include_comments" );
 
+    data.registerOption( m_dialog->iosacl_use_acl_remarks, fwoptions,
+                         "iosacl_use_acl_remarks" );
+
     data.registerOption( m_dialog->iosacl_regroup_commands, fwoptions,
                          "iosacl_regroup_commands" );
 
