@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfAdvancedDialog.cpp 669 2008-11-24 23:49:39Z vadim $
+  $Id: ipfAdvancedDialog.cpp 1047 2009-06-08 21:43:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -86,8 +86,6 @@ ipfAdvancedDialog::ipfAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( m_dialog->ipf_check_shadowing,fwopt, "check_shading"       );
     data.registerOption( m_dialog->ipf_eliminate_duplicates,fwopt, "eliminate_duplicates");
     data.registerOption( m_dialog->ipf_accept_new_tcp_with_no_syn,fwopt, "accept_new_tcp_with_no_syn");
-    data.registerOption( m_dialog->ipf_in_out_code,fwopt, "in_out_code"   );
-    data.registerOption( m_dialog->ipf_pass_all_out,fwopt, "pass_all_out"  );
     data.registerOption( m_dialog->ipf_ignore_empty_groups,fwopt, "ignore_empty_groups");
     data.registerOption( m_dialog->ipf_return_icmp_as_dest,fwopt, "ipf_return_icmp_as_dest");
     data.registerOption( m_dialog->ipf_nat_raudio_proxy,fwopt, "ipf_nat_raudio_proxy");
