@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfAdvancedDialog.h,v 1.2 2004/10/18 05:06:55 vkurland Exp $
+  $Id: ipfAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,25 @@
 #ifndef __IPFADVANCEDDIALOG_H_
 #define __IPFADVANCEDDIALOG_H_
 
-#include "ipfadvanceddialog_q.h"
+#include <ui_ipfadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class ipfAdvancedDialog : public ipfAdvancedDialog_q
+class ipfAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::ipfAdvancedDialog_q         *m_dialog;
 
  public:
     ipfAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~ipfAdvancedDialog();
 
 protected slots:
 
