@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iptAdvancedDialog.h,v 1.5 2005/07/22 04:08:15 vkurland Exp $
+  $Id: iptAdvancedDialog.h 441 2008-08-03 02:24:37Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,27 +27,30 @@
 #ifndef __IPTADVANCEDDIALOG_H_
 #define __IPTADVANCEDDIALOG_H_
 
-#include "iptadvanceddialog_q.h"
+#include <ui_iptadvanceddialog_q.h>
 #include "DialogData.h"
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class iptAdvancedDialog : public iptAdvancedDialog_q
+class iptAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData data;
+    Ui::iptAdvancedDialog_q *m_dialog;
 
  public:
     iptAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~iptAdvancedDialog();
 
 protected slots:
 
     virtual void accept();
     virtual void reject();
+    virtual void help();
 
     virtual void editProlog();
     virtual void editEpilog();
