@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: linksysAdvancedDialog.cpp,v 1.5 2006/03/16 05:38:14 vkurland Exp $
+  $Id: linksysAdvancedDialog.cpp 454 2008-08-06 15:50:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "platforms.h"
 
 #include "linksysAdvancedDialog.h"
-#include "ObjectManipulator.h"
+#include "FWWindow.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -39,17 +39,23 @@
 #include <qcombobox.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
-#include <qwidgetstack.h>
 #include <qregexp.h>
 #include <qtabwidget.h>
 
 using namespace std;
 using namespace libfwbuilder;
 
+linksysAdvancedDialog::~linksysAdvancedDialog()
+{
+    delete m_dialog;
+}
 
 linksysAdvancedDialog::linksysAdvancedDialog(QWidget *parent,FWObject *o)
-    : linksysAdvancedDialog_q(parent)
+    : QDialog(parent)
 {
+    m_dialog = new Ui::linksysAdvancedDialog_q;
+    m_dialog->setupUi(this);
+
     obj=o;
 
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
@@ -61,7 +67,7 @@ linksysAdvancedDialog::linksysAdvancedDialog(QWidget *parent,FWObject *o)
  * since v2.0.3 we do not need to know shell prompt on linksys. Will
  * remove the page completely when code becomes stable.
  */
-    tabWidget3->removePage( tabWidget3->page(1) );
+    m_dialog->tabWidget->removeTab( 1 );
 
     QStringList threeStateMapping;
 
@@ -75,34 +81,34 @@ linksysAdvancedDialog::linksysAdvancedDialog(QWidget *parent,FWObject *o)
     threeStateMapping.push_back("0");
 
 /* set default prompts */
-    if (fwopt->getStr("prompt1").empty()) 
+    if (fwopt->getStr("prompt1").empty())
         Resources::os_res["linksys"]->Resources::setDefaultOption(fwopt,
                            "/FWBuilderResources/Target/options/default/prompt1");
 
-    if (fwopt->getStr("prompt2").empty()) 
+    if (fwopt->getStr("prompt2").empty())
         Resources::os_res["linksys"]->Resources::setDefaultOption(fwopt,
                            "/FWBuilderResources/Target/options/default/prompt2");
-            
-    data.registerOption( linksys_prompt1,
+
+    data.registerOption( m_dialog->linksys_prompt1,
                          fwopt,
                          "prompt1" );
-    data.registerOption( linksys_prompt2,
+    data.registerOption( m_dialog->linksys_prompt2,
                          fwopt,
                          "prompt2" );
 
-    data.registerOption( linksys_path_iptables,
+    data.registerOption( m_dialog->linksys_path_iptables,
                          fwopt,
                          "linux24_path_iptables" );
-    data.registerOption( linksys_path_ip,
+    data.registerOption( m_dialog->linksys_path_ip,
                          fwopt,
                          "linux24_path_ip"       );
-    data.registerOption( linksys_path_lsmod,
+    data.registerOption( m_dialog->linksys_path_lsmod,
                          fwopt,
                          "linux24_path_lsmod"    );
-    data.registerOption( linksys_path_logger,
+    data.registerOption( m_dialog->linksys_path_logger,
                          fwopt,
                          "linux24_path_logger"   );
-    data.registerOption( linksys_path_modprobe,
+    data.registerOption( m_dialog->linksys_path_modprobe,
                          fwopt,
                          "linux24_path_modprobe" );
 
@@ -123,22 +129,22 @@ void linksysAdvancedDialog::accept()
 
     data.saveAll();
 
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
-    linksysAdvancedDialog_q::accept();
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    QDialog::accept();
 }
 
 void linksysAdvancedDialog::reject()
 {
-    linksysAdvancedDialog_q::reject();
+    QDialog::reject();
 }
 
 void linksysAdvancedDialog::setDefaultPrompts()
 {
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
     assert(fwopt!=NULL);
-    linksys_prompt1->setText( 
+    m_dialog->linksys_prompt1->setText(
         Resources::getTargetOptionStr("linksys","default/prompt1").c_str() );
-    linksys_prompt2->setText( 
+    m_dialog->linksys_prompt2->setText(
         Resources::getTargetOptionStr("linksys","default/prompt2").c_str() );
 }
 
