@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: longTextDialog.h,v 1.1 2004/06/26 22:41:10 vkurland Exp $
+  $Id: longTextDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,15 +27,17 @@
 #ifndef __LONGTEXTDIALOG_H_
 #define __LONGTEXTDIALOG_H_
 
-#include "config.h"
-#include <longtextdialog_q.h>
+#include "../../config.h"
+#include <ui_longtextdialog_q.h>
 
-class longTextDialog : public longTextDialog_q
+class longTextDialog : public QDialog
 {
     Q_OBJECT
+    Ui::longTextDialog_q *m_dialog;
 
  public:
     longTextDialog(QWidget *p,const QString &txt,const QString &ltxt);
+    ~longTextDialog();
     
 };
 
