@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: macosxAdvancedDialog.cpp,v 1.3 2006/03/16 05:38:14 vkurland Exp $
+  $Id: macosxAdvancedDialog.cpp 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "platforms.h"
 
 #include "macosxAdvancedDialog.h"
-#include "ObjectManipulator.h"
+#include "FWWindow.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -38,17 +38,23 @@
 #include <qcombobox.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
-#include <qwidgetstack.h>
 #include <qregexp.h>
 
 
 using namespace std;
 using namespace libfwbuilder;
 
+macosxAdvancedDialog::~macosxAdvancedDialog()
+{
+    delete m_dialog;
+}
 
 macosxAdvancedDialog::macosxAdvancedDialog(QWidget *parent,FWObject *o)
-    : macosxAdvancedDialog_q(parent)
+    : QDialog(parent)
 {
+    m_dialog = new Ui::macosxAdvancedDialog_q;
+    m_dialog->setupUi(this);
+
     obj=o;
 
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
@@ -68,19 +74,19 @@ macosxAdvancedDialog::macosxAdvancedDialog(QWidget *parent,FWObject *o)
     threeStateMapping.push_back(QObject::tr("Off"));
     threeStateMapping.push_back("0");
 
-    data.registerOption(  macosx_ip_forward,
+    data.registerOption( m_dialog->macosx_ip_forward,
                           fwopt,
                           "macosx_ip_forward", threeStateMapping);
-    data.registerOption(  macosx_ip_redirect,
+    data.registerOption( m_dialog->macosx_ip_redirect,
                           fwopt,
                           "macosx_ip_redirect", threeStateMapping);
-    data.registerOption(  macosx_ip_sourceroute,
+    data.registerOption( m_dialog->macosx_ip_sourceroute,
                           fwopt,
                           "macosx_ip_sourceroute", threeStateMapping);
-    data.registerOption(  macosx_path_ipfw,
+    data.registerOption( m_dialog->macosx_path_ipfw,
                           fwopt,
                           "macosx_path_ipfw");
-    data.registerOption(  macosx_path_sysctl,
+    data.registerOption( m_dialog->macosx_path_sysctl,
                           fwopt,
                           "macosx_path_sysctl");
 
@@ -101,13 +107,13 @@ void macosxAdvancedDialog::accept()
 
     data.saveAll();
 
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
-    macosxAdvancedDialog_q::accept();
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    QDialog::accept();
 }
 
 void macosxAdvancedDialog::reject()
 {
-    macosxAdvancedDialog_q::reject();
+    QDialog::reject();
 }
 
 
