@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newFirewallDialog.cpp 986 2009-05-31 21:22:59Z vadim $
+  $Id: newFirewallDialog.cpp 1358 2009-08-27 16:59:30Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -519,10 +519,15 @@ void newFirewallDialog::fillInterfaceSLList()
     }
 }
 
+/*
+ * this slot is connected to currentItemChanged signal of templateList
+ * As a side effect, this slot is called when we clear templateList.
+ */
 void newFirewallDialog::templateSelected(QListWidgetItem *itm)
 {
-    FWObject *o=templates[itm];
-    assert (o!=NULL);
+    if (templates.size()==0) return;
+    FWObject *o = templates[itm];
+    if (o==NULL) return;
 
     Firewall *fw = Firewall::cast(o);
 
