@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: openbsdAdvancedDialog.cpp,v 1.3 2006/03/16 05:38:14 vkurland Exp $
+  $Id: openbsdAdvancedDialog.cpp 390 2008-07-18 22:56:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "platforms.h"
 
 #include "openbsdAdvancedDialog.h"
-#include "ObjectManipulator.h"
+#include "FWWindow.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -38,17 +38,23 @@
 #include <qcombobox.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
-#include <qwidgetstack.h>
+#include <qstackedwidget.h>
 #include <qregexp.h>
 
 
 using namespace std;
 using namespace libfwbuilder;
 
+openbsdAdvancedDialog::~openbsdAdvancedDialog()
+{
+    delete m_dialog;
+}
 
 openbsdAdvancedDialog::openbsdAdvancedDialog(QWidget *parent,FWObject *o)
-    : openbsdAdvancedDialog_q(parent)
+    : QDialog(parent)
 {
+    m_dialog = new Ui::openbsdAdvancedDialog_q;
+    m_dialog->setupUi(this);
     obj=o;
 
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
@@ -68,22 +74,25 @@ openbsdAdvancedDialog::openbsdAdvancedDialog(QWidget *parent,FWObject *o)
     threeStateMapping.push_back(QObject::tr("Off"));
     threeStateMapping.push_back("0");
 
-    data.registerOption(  openbsd_ip_sourceroute,
+    data.registerOption( m_dialog->openbsd_ip_sourceroute,
                           fwopt,
-                          "openbsd_ip_sourceroute",        threeStateMapping);
-    data.registerOption(  openbsd_ip_redirect,
+                          "openbsd_ip_sourceroute", threeStateMapping);
+    data.registerOption( m_dialog->openbsd_ip_redirect,
                           fwopt,
-                          "openbsd_ip_redirect",           threeStateMapping);
-    data.registerOption(  openbsd_ip_directed_broadcast,
+                          "openbsd_ip_redirect", threeStateMapping);
+    data.registerOption( m_dialog->openbsd_ip_directed_broadcast,
                           fwopt,
                           "openbsd_ip_directed_broadcast", threeStateMapping);
-    data.registerOption(  openbsd_ip_forward,
+    data.registerOption( m_dialog->openbsd_ip_forward,
                           fwopt,
-                          "openbsd_ip_forward",            threeStateMapping);
-    data.registerOption(  openbsd_path_pfctl,
+                          "openbsd_ip_forward", threeStateMapping);
+    data.registerOption( m_dialog->openbsd_ipv6_forward,
+                          fwopt,
+                          "openbsd_ipv6_forward", threeStateMapping);
+    data.registerOption( m_dialog->openbsd_path_pfctl,
                           fwopt,
                           "openbsd_path_pfctl");
-    data.registerOption(  openbsd_path_sysctl,
+    data.registerOption( m_dialog->openbsd_path_sysctl,
                           fwopt,
                           "openbsd_path_sysctl");
 
@@ -104,13 +113,13 @@ void openbsdAdvancedDialog::accept()
 
     data.saveAll();
 
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
-    openbsdAdvancedDialog_q::accept();
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    QDialog::accept();
 }
 
 void openbsdAdvancedDialog::reject()
 {
-    openbsdAdvancedDialog_q::reject();
+    QDialog::reject();
 }
 
 
