@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pfAdvancedDialog.cpp 705 2008-12-21 20:48:24Z vadim $
+  $Id: pfAdvancedDialog.cpp 1302 2009-08-10 22:33:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -115,7 +115,7 @@ pfAdvancedDialog::pfAdvancedDialog(QWidget *parent,FWObject *o)
                          "ignore_empty_groups");
 //    data.registerOption( pf_use_tables, fwopt, "use_tables");
     data.registerOption( m_dialog->pf_accept_new_tcp_with_no_syn,fwopt, "accept_new_tcp_with_no_syn");
-    data.registerOption( m_dialog->pf_modulate_state,fwopt, "modulate_state");
+    data.registerOption( m_dialog->pf_modulate_state,fwopt, "pf_modulate_state");
     data.registerOption( m_dialog->pf_scrub_random_id,fwopt, "pf_scrub_random_id");
 
     data.registerOption( m_dialog->pf_do_scrub,fwopt, "pf_do_scrub");
@@ -190,10 +190,26 @@ pfAdvancedDialog::pfAdvancedDialog(QWidget *parent,FWObject *o)
 
 /* page "Prolog/Epilog" */
 
-    slm = getPrologPlaces( obj->getStr("platform").c_str());
+    QStringList prologPlaces_pf;
+    prologPlaces_pf.push_back(QObject::tr("in the activation shell script"));
+    prologPlaces_pf.push_back("fw_file");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, at the very top"));
+    prologPlaces_pf.push_back("pf_file_top");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after set comamnds"));
+    prologPlaces_pf.push_back("pf_file_after_set");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after scrub comamnds"));
+    prologPlaces_pf.push_back("pf_file_after_scrub");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after table definitions"));
+    prologPlaces_pf.push_back("pf_file_after_tables");
+
     m_dialog->prologPlace->clear();
-    m_dialog->prologPlace->addItems(getScreenNames(slm));
-    data.registerOption( m_dialog->prologPlace, fwopt, "prolog_place", slm);
+    m_dialog->prologPlace->addItems(getScreenNames(prologPlaces_pf));
+    data.registerOption( m_dialog->prologPlace, fwopt, "prolog_place",
+                         prologPlaces_pf);
 
     data.registerOption( m_dialog->prolog_script, fwopt, "prolog_script");
     data.registerOption( m_dialog->epilog_script, fwopt, "epilog_script");
