@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp 929 2009-05-12 22:43:57Z vadim $
+  $Id: platforms.cpp 1154 2009-07-14 21:26:34Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -50,8 +50,6 @@ QStringList logFacilities;
 QStringList actionsOnReject;
 QStringList routeOptions_pf_ipf;
 QStringList routeLoadOptions_pf;
-QStringList prologPlaces_ipt;
-QStringList prologPlaces_pf;
 QStringList limitSuffixes;
 
 void init_platforms()
@@ -156,28 +154,6 @@ void init_platforms()
     routeLoadOptions_pf.push_back(QObject::tr("Round Robin"));
     routeLoadOptions_pf.push_back("round_robin");
 
-    prologPlaces_ipt.push_back(QObject::tr("on top of the script"));
-    prologPlaces_ipt.push_back("top");
-    prologPlaces_ipt.push_back(QObject::tr("after interface configuration"));
-    prologPlaces_ipt.push_back("after_interfaces");
-    prologPlaces_ipt.push_back(QObject::tr("after policy reset"));
-    prologPlaces_ipt.push_back("after_flush");
-
-    prologPlaces_pf.push_back(QObject::tr("in the activation shell script"));
-    prologPlaces_pf.push_back("fw_file");
-
-    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, at the very top"));
-    prologPlaces_pf.push_back("pf_file_top");
-
-    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after set comamnds"));
-    prologPlaces_pf.push_back("pf_file_after_set");
-
-    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after scrub comamnds"));
-    prologPlaces_pf.push_back("pf_file_after_scrub");
-
-    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after table definitions"));
-    prologPlaces_pf.push_back("pf_file_after_tables");
-
     limitSuffixes.push_back("");
     limitSuffixes.push_back("");
     limitSuffixes.push_back(QObject::tr("/day"));
@@ -399,6 +375,7 @@ list<QStringPair> getVersionsForPlatform(const QString &platform)
         res.push_back(QStringPair("1.2.9", QObject::tr("1.2.9 to 1.2.11")));
         res.push_back(QStringPair("1.3.0", QObject::tr("1.3.x")));
         res.push_back(QStringPair("1.4.0", QObject::tr("1.4.0 or later")));
+        res.push_back(QStringPair("1.4.3", QObject::tr("1.4.3 or later")));
     } else
     {
         if (platform=="pix" || platform=="fwsm" || platform=="iosacl")
@@ -483,14 +460,6 @@ const QStringList& getRouteLoadOptions_pf(const QString&)
     return routeLoadOptions_pf;
 }
 
-const QStringList& getPrologPlaces(const QString &platform)
-{
-    if (platform=="pf")
-        return prologPlaces_pf;
-    else
-        return prologPlaces_ipt;
-}
-
 const QStringList& getLimitSuffixes(const QString&)
 {
     return limitSuffixes;
