@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.h 749 2009-01-24 08:01:32Z vadim $
+  $Id: platforms.h 1153 2009-07-13 23:14:55Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -86,11 +86,6 @@ const QStringList& getRouteOptions_pf_ipf(const QString &platform);
 
 const QStringList& getRouteLoadOptions_pf(const QString &platform);
 
-/**
- * returns a list of Prolog places (mapping list)
- */
-const QStringList& getPrologPlaces(const QString &platform);
-
 /**
  * returns a list of Limit Suffixes (mapping list)
  */
