@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: solarisAdvancedDialog.h,v 1.1 2004/05/11 04:45:39 vkurland Exp $
+  $Id: solarisAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,25 @@
 #ifndef __SOLARISADVANCEDDIALOG_H_
 #define __SOLARISADVANCEDDIALOG_H_
 
-#include "solarisadvanceddialog_q.h"
+#include <ui_solarisadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class solarisAdvancedDialog : public solarisAdvancedDialog_q
+class solarisAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::solarisAdvancedDialog_q     *m_dialog;
 
  public:
     solarisAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~solarisAdvancedDialog();
 
 protected slots:
 
