@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils_no_qt.cpp 410 2008-07-25 04:42:30Z vadim $
+  $Id: utils_no_qt.cpp 748 2009-01-24 07:17:05Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -93,14 +93,18 @@ void findByObjectType(FWObject *o,
     }
 }
 
-
-FWReference* findRef(FWObject *o, FWObject *p)
+/** 
+ * Find reference to object <o> in the group <container> and return
+ * pointer to that reference object. If no such reference exists,
+ * return NULL.
+ */
+FWReference* findRef(FWObject *o, FWObject *container)
 {
     FWReference* ref=NULL;
-    FWObject::iterator i=p->begin();
-    for(;i!=p->end();++i)
+    FWObject::iterator i = container->begin();
+    for(; i!=container->end(); ++i)
     {
-        ref=FWReference::cast(*i);
+        ref = FWReference::cast(*i);
         if (ref!=NULL && ref->getPointer() == o)
         {
             break;
