@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_iosacl.cpp 338 2008-07-07 18:29:33Z vadim $
+  $Id: PolicyCompiler_iosacl.cpp 786 2009-03-19 05:03:02Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -84,111 +84,6 @@ int PolicyCompiler_iosacl::prolog()
 
     output << "!################"  << endl;
 
-    if ( fw->getOptionsObject()->getBool("iosacl_acl_substitution") )
-    {
-        /* Generate short temporary ACL and assign it to all
-         * interfaces. This ACL permits IPSEC (IP proto 50 and UDP port 500)
-         as well as ssh from given subnet to any.
-        */
-
-        string temp_acl = "tmp_acl";
-        string temp_acl_addr = fw->getOptionsObject()->getStr("iosacl_acl_temp_addr");
-        if (temp_acl_addr.empty())
-        {
-            abort("Missing address for management host or subnet for temporary ACL.\nPlease enter it in the tab 'Script options' in 'Firewall Settings' dialog");
-        }
-
-        string::size_type slash_idx = temp_acl_addr.find('/');
-        string addr = temp_acl_addr;
-        string netmask = "255.255.255.255";
-
-        if (slash_idx!=string::npos)
-        {
-            addr = temp_acl_addr.substr(0,slash_idx);
-            netmask = temp_acl_addr.substr(slash_idx+1);
-            try
-            {
-                if (netmask.find(".")!=string::npos)
-                {
-                    InetAddr nm(netmask);
-                    nm.getLength(); // to avoid warning abt unused var
-                } else
-                {
-                    int nm_length;
-                    istringstream  str(netmask);
-                    str >> nm_length;
-                    InetAddr nm(nm_length);
-                    netmask = nm.toString();
-                }
-            } catch(FWException &ex)
-            {
-                abort("Invalid netmask for management subnet: '"+netmask+"'");
-            }
-        }
-
-        try
-        {
-            InetAddr a(addr);
-            a.isAny();
-        } catch(FWException &ex)
-        {
-            abort("Invalid address for management subnet: '"+addr+"'");
-        }
-
-        string clearACLcmd = Resources::platform_res[platform]->getResourceStr(
-            string("/FWBuilderResources/Target/options/")+
-               "version_"+version+"/iosacl_commands/clear_ip_acl");
-
-        output << endl;
-
-
-        // cisco uses "wildcards" instead of netmasks
-
-        //long nm = InetAddr(netmask).to32BitInt();
-        //struct in_addr na;
-        //na.s_addr = ~nm;
-        InetAddr nnm( ~(InetAddr(netmask)) );
-
-        string addr_family_prefix = "ip";
-        if (ipv6) addr_family_prefix = "ipv6";
-
-        output << clearACLcmd << " " << temp_acl << endl;
-        output << addr_family_prefix
-               << " access-list extended " << temp_acl << endl;
-        output << "  permit ip "
-               << addr << " " << nnm.toString() << " any " << endl;
-        output << "  deny " << addr_family_prefix
-               << " any any " << endl;
-        output << "exit" << endl;
-        output << endl;
-
-        // find management interface
-        int nmi = 0;
-        list<FWObject*> ll = fw->getByType(Interface::TYPENAME);
-        for (FWObject::iterator i=ll.begin(); i!=ll.end(); i++)
-        {
-            Interface *intf = Interface::cast( *i );
-            if (intf->isManagement())
-            {
-                nmi++;
-                output << "interface " << intf->getName() << endl;
-                output << "  no " << addr_family_prefix
-                       << " access-group in" << endl;
-                output << "  no " << addr_family_prefix
-                       << " access-group out" << endl;
-                output << "  " << addr_family_prefix
-                       << " access-group " << temp_acl << " in" << endl;
-                output << "exit" << endl;
-            }
-        }
-        if (nmi==0)
-        {
-            abort("One of the interfaces of the firewall must be marked as management interface.");
-        }
-
-        output << endl;
-    }
-
     return PolicyCompiler::prolog();
 }
 
@@ -334,16 +229,20 @@ void PolicyCompiler_iosacl::compile()
                  "expand objects with multiple addresses in DST" ) );
         add( new MACFiltering(
                  "check for MAC address filtering" ) );
-        add( new dropRuleWithEmptyRE(
-                 "drop rules with empty rule elements"));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
+
 //        add( new splitByNetworkZonesForDst ("split rule if objects in Dst belong to different network zones " ) );
 
-        add( new checkForUnnumbered(
-                 "check for unnumbered interfaces" ) );
+        if (ipv6)
+            add( new DropIPv4Rules("drop ipv4 rules"));
+        else
+            add( new DropIPv6Rules("drop ipv6 rules"));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
+
+        add( new checkForUnnumbered("check for unnumbered interfaces"));
 
         add( new addressRanges ("process address ranges" ) );
-        add( new dropRuleWithEmptyRE(
-                 "drop rules with empty rule elements"));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
 
         add( new setInterfaceAndDirectionBySrc(
     "Set interface and direction for rules with interface 'all' using SRC"));
@@ -410,8 +309,9 @@ string PolicyCompiler_iosacl::printAccessGroupCmd(ciscoACL *acl)
         if (acl->direction()=="out" || acl->direction()=="Outbound") dir="out";
 
         str << "interface " << acl->getInterface()->getName() << endl;
-        str << "  " << addr_family_prefix
-            << " access-group " << acl->workName() << " " << dir << endl;
+        str << "  " << addr_family_prefix << " ";
+        str << getAccessGroupCommandForAddressFamily(ipv6);
+        str << " " << acl->workName() << " " << dir << endl;
         str << "exit" << endl;
     }
     return str.str();
@@ -435,3 +335,8 @@ void PolicyCompiler_iosacl::epilog()
     }
 }
 
+string PolicyCompiler_iosacl::getAccessGroupCommandForAddressFamily(bool ipv6)
+{
+    if (ipv6) return "traffic-filter";
+    return "access-group";
+}
