@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_iosacl_writers.cpp 1051 2009-06-11 20:17:10Z vadim $
+  $Id: PolicyCompiler_iosacl_writers.cpp 1402 2009-09-06 02:34:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -60,6 +60,7 @@
 
 #include <assert.h>
 
+
 using namespace libfwbuilder;
 using namespace fwcompiler;
 using namespace std;
@@ -280,7 +281,9 @@ string PolicyCompiler_iosacl::PrintRule::_printRule(PolicyRule *rule)
 //    aclstr << endl;
 
     if (compiler->fw->getOptionsObject()->getBool("iosacl_use_acl_remarks"))
-        ruleout << acl->addRemark( rule->getLabel() );
+    {
+        ruleout << acl->addRemark(rule->getLabel(), rule->getComment());
+    }
 
     ruleout << acl->addLine(aclstr.str());
 
@@ -395,7 +398,7 @@ string PolicyCompiler_iosacl::PrintRule::_printDstService(Service *srv)
     if (TCPService::isA(srv) && srv->getBool("established"))
         str << "established ";
 
-    if (ICMPService::isA(srv) && srv->getInt("type")!=-1)
+    if ((ICMPService::isA(srv) || ICMP6Service::isA(srv)) && srv->getInt("type")!=-1)
 	    str << srv->getStr("type") << " ";
 
     if (CustomService::isA(srv)) 
