@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipf.cpp 443 2008-08-03 16:47:47Z vadim $
+  $Id: ipf.cpp 658 2008-11-22 19:14:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -91,29 +91,56 @@ static const char      *fwobjectname   = NULL;
 static string           fw_file_name   = "";
 static string           ipf_file_name  = "";
 static string           nat_file_name  = "";
+static string           output_dir     = "";
 static int              dl             = 0;
 static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
 static bool             test_mode      = false;
+static bool             fw_by_id       = false;
 
 FWObjectDatabase       *objdb = NULL;
 
+#ifdef _WIN32
+string fs_separator = "\\";
+#else
+string fs_separator = "/";
+#endif
+
+string getFileName(const string &file_path)
+{
+    string::size_type n = file_path.rfind(fs_separator);
+    string res = file_path;
+    res.erase(0, n+1);
+    return res;
+}
+
+string getDir(const string &file_path)
+{
+    string::size_type n = file_path.rfind(fs_separator);
+    string res = file_path;
+    if (n==string::npos) return "";
+    else res.erase(n);
+    return res;
+}
+
 class UpgradePredicate: public XMLTools::UpgradePredicate
 {
     public:
     virtual bool operator()(const string&) const 
     { 
-	cout << _("Data file has been created in the old version of Firewall Builder. Use fwbuilder GUI to convert it.") << endl;
+	cout << "Data file has been created in the old version of ";
+        cout << "Firewall Builder. Use fwbuilder GUI to convert it." << endl;
 	return false;
     }
 };
     
 void usage(const char *name)
 {
-    cout << _("Firewall Builder:  policy compiler for ipfilter") << endl;
-    cout << _("Version ") << VERSION << RELEASE_NUM << endl;
-    cout << _("Usage: ") << name << " [-x] [-v] [-V] [-f filename.xml] [-o output.fw] [-d destdir] [-m] firewall_object_name" << endl;
+    cout << "Firewall Builder:  policy compiler for ipfilter" << endl;
+    cout << "Version " << VERSION << RELEASE_NUM << endl;
+    cout << "Usage: " << name
+         << " [-x] [-v] [-V] [-f filename.xml] [-o output.fw] [-d destdir] [-m] firewall_object_name" << endl;
 }
 
 string printActivationCommandWithSubstitution(Firewall *fw,string filePath,string cmd)
@@ -159,10 +186,13 @@ int main(int argc, char * const *argv)
 
     int   opt;
 
-    while( (opt=getopt(argc,argv,"x:vVf:d:r:o:")) != EOF )
+    while( (opt=getopt(argc,argv,"x:ivVf:d:r:o:")) != EOF )
     {
         switch(opt)
         {
+        case 'i':
+            fw_by_id = true;
+            break;
         case 'd':
             wdir = strdup(optarg);
             break;
@@ -211,22 +241,6 @@ int main(int argc, char * const *argv)
 
     fwobjectname = strdup( argv[optind++] );
 
-    if (fw_file_name.empty())
-    {
-        fw_file_name=string(fwobjectname)+".fw";
-        ipf_file_name=string(fwobjectname)+"-ipf.conf";
-        nat_file_name=string(fwobjectname)+"-nat.conf";
-    } else
-    {
-        string::size_type n = fw_file_name.rfind(".");
-        ipf_file_name = fw_file_name;
-        ipf_file_name.erase(n);
-        ipf_file_name.append("-ipf.conf");
-        nat_file_name = fw_file_name;
-        nat_file_name.erase(n);
-        nat_file_name.append("-nat.conf");
-    }
-
     if (wdir==0) 	wdir="./";
 
     if (
@@ -236,7 +250,7 @@ int main(int argc, char * const *argv)
     chdir(wdir)
 #endif
     ) {
-	cerr << _("Can't change to: ") << wdir << endl;
+	cerr << "Can't change to: " << wdir << endl;
 	exit(1);
     }
 
@@ -251,7 +265,7 @@ int main(int argc, char * const *argv)
 	/* load the data file */
 	UpgradePredicate upgrade_predicate; 
 
-	if (verbose) cout << _(" *** Loading data ...");
+	if (verbose) cout << " *** Loading data ...";
 
         objdb->setReadOnly( false );
         objdb->load( sysfname, &upgrade_predicate, librespath);
@@ -264,15 +278,46 @@ int main(int argc, char * const *argv)
         objdb->reIndex();
 
 //	objdb->load(filename,  &upgrade_predicate, librespath);
-	if (verbose) cout << _(" done\n");
+	if (verbose) cout << " done\n";
 
         FWObject *slib = objdb->getById(FWObjectDatabase::STANDARD_LIB_ID);
         if (slib && slib->isReadOnly()) slib->setReadOnly(false);
 
 	/* Review firewall and OS options and generate commands */
-	Firewall*  fw=objdb->findFirewallByName(fwobjectname);
- 
-	if (verbose) cout << _(" *** Data checks ...");
+	Firewall* fw;
+        if (fw_by_id)
+        {
+            // fwobjectname is actually object id
+            fw = Firewall::cast(
+                objdb->findInIndex(objdb->getIntId(fwobjectname)));
+            fwobjectname = fw->getName().c_str();
+        }
+        else
+            fw = objdb->findFirewallByName(fwobjectname);
+
+        if (fw_file_name.empty())
+        {
+            fw_file_name = string(fwobjectname)+".fw";
+            ipf_file_name = string(fwobjectname)+"-ipf.conf";
+            nat_file_name = string(fwobjectname)+"-nat.conf";
+            output_dir = "";
+        } else
+        {
+            ipf_file_name = getFileName(fw_file_name);
+            string::size_type n = ipf_file_name.rfind(".");
+            ipf_file_name.erase(n);
+            ipf_file_name.append("-ipf.conf");
+
+            nat_file_name = getFileName(fw_file_name);
+            n = nat_file_name.rfind(".");
+            nat_file_name.erase(n);
+            nat_file_name.append("-nat.conf");
+
+            output_dir = getDir(fw_file_name);
+            if (!output_dir.empty()) output_dir += "/";
+        }
+
+	if (verbose) cout << " *** Data checks ...";
 
         /* some initial sanity checks */
         list<FWObject*> l2=fw->getByType(Interface::TYPENAME);
@@ -287,17 +332,21 @@ int main(int argc, char * const *argv)
                 if (l3.size()>0)
                 {
                     char errstr[256];
-                    for (list<FWObject*>::iterator j=l3.begin(); j!=l3.end(); ++j) 
+                    for (list<FWObject*>::iterator j=l3.begin();
+                         j!=l3.end(); ++j) 
                         if ( objdb->findAllReferences(*j).size()!=0 )
                         {
                             sprintf(errstr,
-                                    _("Dynamic interface %s has an IP address that is used in the firewall policy rule.\n"),
+                                    "Dynamic interface %s has an IP address "
+                                    "that is used in the firewall policy rule.\n",
                                     iface->getName().c_str() );
                             throw FWException(errstr);
                         }
 
                     sprintf(errstr,
-                            _("Dynamic interface %s should not have an IP address object attached to it. This IP address object will be ignored.\n"),
+                            "Dynamic interface %s should not have an IP address"
+                            " object attached to it. This IP address object "
+                            "will be ignored.\n",
                             iface->getName().c_str() );
                     cerr << errstr;
                     for (list<FWObject*>::iterator j=l3.begin(); j!=l3.end(); ++j) 
@@ -310,7 +359,7 @@ int main(int argc, char * const *argv)
                 if ( iface->isRegular() && la.empty() )
                 {
                     char errstr[256];
-                    sprintf(errstr,_("Missing IP address for interface %s\n"),
+                    sprintf(errstr, "Missing IP address for interface %s\n",
                             iface->getName().c_str() );
                     throw FWException(errstr);
                 }
@@ -322,7 +371,7 @@ int main(int argc, char * const *argv)
                     {
                         char errstr[256];
                         sprintf(errstr,
-                      _("Interface %s has IP address \"0.0.0.0\".\n"),
+                                "Interface %s has IP address \"0.0.0.0\".\n",
                                 iface->getName().c_str() );
                         throw FWException(errstr);
                     }
@@ -331,7 +380,7 @@ int main(int argc, char * const *argv)
 
         }
 
-	if (verbose) cout << _(" done\n");
+	if (verbose) cout << " done\n";
 
 	FWOptions* options=fw->getOptionsObject();
 	string s;
@@ -361,7 +410,8 @@ int main(int argc, char * const *argv)
             oscnf=new OSConfigurator_freebsd(objdb , fwobjectname, false);
 
 	if (oscnf==NULL)
-	    throw FWException(_("Unrecognized host OS ")+fw->getStr("host_OS")+"  (family "+family+")");
+	    throw FWException("Unrecognized host OS " + 
+                              fw->getStr("host_OS")+"  (family "+family+")");
 
 	oscnf->prolog();
 
@@ -420,7 +470,7 @@ int main(int argc, char * const *argv)
             user_name=getenv("LOGNAME");
             if (user_name==NULL)
             {
-                cerr << _("Can't figure out your user name, aborting") << endl;
+                cerr << "Can't figure out your user name, aborting" << endl;
                 exit(1);
             }
         }
@@ -435,19 +485,19 @@ int main(int argc, char * const *argv)
 #endif
 	fw_file << "#!/bin/sh " << shell_dbg << endl << endl;
 
-        fw_file << _("#\n\
+        fw_file << "#\n\
 #  This is automatically generated file. DO NOT MODIFY !\n\
 #\n\
-#  Firewall Builder  fwb_ipf v") << VERSION << "-" << RELEASE_NUM << _(" \n\
+#  Firewall Builder  fwb_ipf v" << VERSION << "-" << RELEASE_NUM << " \n\
 #\n\
-#  Generated ") << timestr << " " << tzname[stm->tm_isdst] << _(" by ") 
+#  Generated " << timestr << " " << tzname[stm->tm_isdst] << " by "
                << user_name << "\n#\n#\n";
 
-        fw_file << MANIFEST_MARKER << "* " << fw_file_name << endl;
+        fw_file << MANIFEST_MARKER << "* " << getFileName(fw_file_name) << endl;
       	if (have_ipf) 
-            fw_file << MANIFEST_MARKER << "  " << ipf_file_name << endl;
+            fw_file << MANIFEST_MARKER << "  " << getFileName(ipf_file_name) << endl;
       	if (have_nat) 
-            fw_file << MANIFEST_MARKER << "  " << nat_file_name << endl;
+            fw_file << MANIFEST_MARKER << "  " << getFileName(nat_file_name) << endl;
         fw_file << "#" << endl;
         fw_file << "#" << endl;
 
@@ -470,8 +520,8 @@ int main(int argc, char * const *argv)
         fw_file << endl;
 
         fw_file << "log '";
-        fw_file << _("Activating firewall script generated ")
-               << timestr << " " << _(" by ")
+        fw_file << "Activating firewall script generated "
+               << timestr << " " << " by "
                << user_name;
         fw_file << "'" << endl;
 
@@ -501,16 +551,18 @@ int main(int argc, char * const *argv)
         fw_file << "# End of prolog script" << endl;
         fw_file << "#" << endl;
 
-        unlink(ipf_file_name.c_str());
+        string file_name = output_dir + ipf_file_name;
+
+        unlink(file_name.c_str());
       	if (have_ipf) 
         {
             ofstream ipf_file;
             ipf_file.exceptions(ofstream::eofbit|ofstream::failbit|ofstream::badbit);
         
 #ifdef _WIN32
-            ipf_file.open(ipf_file_name.c_str(), ios::out|ios::binary);
+            ipf_file.open(file_name.c_str(), ios::out|ios::binary);
 #else
-            ipf_file.open(ipf_file_name.c_str());
+            ipf_file.open(file_name.c_str());
 #endif
 
             if (c.haveErrorsAndWarnings())
@@ -524,28 +576,30 @@ int main(int argc, char * const *argv)
 	    ipf_file.close();
 
             string cmd = string("$IPF ")+ipf_dbg+" -I -f ";
-            string filePath = string("${FWDIR}/")+ipf_file_name;
+            string filePath = string("${FWDIR}/") + ipf_file_name;
             if (fw->getOptionsObject()->getBool("dynAddr"))
             {
                 cmd += "-";
                 fw_file << 
-                    printActivationCommandWithSubstitution(fw,filePath,cmd);
+                    printActivationCommandWithSubstitution(fw, filePath, cmd);
             } else
             {
                 fw_file << cmd << filePath << endl;
             }
 	}
 
-        unlink(nat_file_name.c_str());
+        file_name = output_dir + nat_file_name;
+
+        unlink(file_name.c_str());
 	if (have_nat) 
         {
             ofstream nat_file;
             nat_file.exceptions(ofstream::eofbit|ofstream::failbit|ofstream::badbit);
 
 #ifdef _WIN32
-            nat_file.open(nat_file_name.c_str(), ios::out|ios::binary);
+            nat_file.open(file_name.c_str(), ios::out|ios::binary);
 #else
-            nat_file.open(nat_file_name.c_str());
+            nat_file.open(file_name.c_str());
 #endif
 
             if (n.haveErrorsAndWarnings())
@@ -600,7 +654,7 @@ int main(int argc, char * const *argv)
         chmod(fw_file_name.c_str(),S_IXUSR|S_IRUSR|S_IWUSR|S_IRGRP);
 #endif
         
-        cout << _(" Compiled successfully") << endl << flush;
+        cout << " Compiled successfully" << endl << flush;
         
         return 0;
 
@@ -621,7 +675,7 @@ int main(int argc, char * const *argv)
 	cerr << ex.what();
         return 1;
     } catch (...) {
-	cerr << _("Unsupported exception");
+	cerr << "Unsupported exception";
         return 1;
     }
 
