@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: MangleTableCompiler_ipt.cpp 752 2009-01-30 04:54:03Z vadim $
+  $Id: MangleTableCompiler_ipt.cpp 800 2009-04-11 00:53:50Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -147,7 +147,7 @@ string MangleTableCompiler_ipt::printAutomaticRulesForMangleTable(
 
     PolicyCompiler_ipt::PrintRule *prp = createPrintRuleProcessor();
 
-    res << prp->_declareTable();
+    // res << prp->_declareTable();
 
     if (have_connmark)
     {
