@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_PrintRuleIptRst.cpp 800 2009-04-11 00:53:50Z vadim $
+  $Id: NATCompiler_PrintRuleIptRst.cpp 1154 2009-07-14 21:26:34Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -61,7 +61,7 @@ string NATCompiler_ipt::PrintRuleIptRst::_createChain(const string &chain)
     string res;
     NATCompiler_ipt *ipt_comp = dynamic_cast<NATCompiler_ipt*>(compiler);
 
-    if (!minus_n_tracker_initialized) InitializeMinusNTracker();
+    if (!minus_n_tracker_initialized) initializeMinusNTracker();
 
     if ( ipt_comp->minus_n_commands->count(chain)==0 )
     {
