@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp 1049 2009-06-10 20:28:00Z vadim $
+  $Id: NATCompiler_ipt.cpp 1303 2009-08-12 17:51:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -336,23 +336,64 @@ bool NATCompiler_ipt::splitSDNATRule::processNext()
         RuleElementOSrv *osrv;
         RuleElementTSrc *tsrc;
         RuleElementTDst *tdst;
+        RuleElementTSrv *tsrv;
+
+        bool tsrv_translates_src_port = false;
+        bool tsrv_translates_dst_port = false;
+
+        Service  *osrv_obj = compiler->getFirstOSrv(rule);
+        Service  *tsrv_obj = compiler->getFirstTSrv(rule);
+        
+        if (TCPUDPService::cast(osrv_obj) && TCPUDPService::cast(tsrv_obj))
+        {
+            TCPUDPService *tu_osrv = TCPUDPService::cast(osrv_obj);
+            TCPUDPService *tu_tsrv = TCPUDPService::cast(tsrv_obj);
+
+            tsrv_translates_src_port =
+                (tu_tsrv->getSrcRangeStart() != 0 && tu_tsrv->getDstRangeStart() == 0);
+            tsrv_translates_dst_port =
+                (tu_tsrv->getSrcRangeStart() == 0 && tu_tsrv->getDstRangeStart() != 0);
+
+            if (tsrv_translates_dst_port &&
+                tu_osrv->getDstRangeStart() == tu_tsrv->getDstRangeStart() &&
+                tu_osrv->getDstRangeEnd() == tu_tsrv->getDstRangeEnd())
+                tsrv_translates_dst_port = false;  // osrv and tsrv define the same ports
+
+            if (tsrv_translates_src_port &&
+                tu_osrv->getSrcRangeStart() == tu_tsrv->getSrcRangeStart() &&
+                tu_osrv->getSrcRangeEnd() == tu_tsrv->getSrcRangeEnd())
+                tsrv_translates_src_port = false;  // osrv and tsrv define the same ports
+        }
 
 /* first rule translates destination and may translate service (depends
- * on the original rule) */
+ * on the original rule). Set type to Unknown because this may become
+ * DNAT or DNetNat - we will decide later.
+ */
         NATRule *r = compiler->dbcopy->createNATRule();
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
         r->setRuleType(NATRule::Unknown);
                 
-        tsrc=r->getTSrc();
+        tsrc = r->getTSrc();
         tsrc->clearChildren();
         tsrc->setAnyElement();
 
+/* this rule translates destination and can't deal with source port
+ * translation. Leave that to the second rule
+ */
+        if (tsrv_translates_src_port)
+        {
+            tsrv = r->getTSrv();
+            tsrv->clearChildren();
+            tsrv->setAnyElement();
+        }
+
         tmp_queue.push_back(r);
 
 /* the second rule translates source and uses translated object in
  * ODst. Since the service could have been translated by the first
- * rule, we use TSrv in OSrv */
+ * rule, we use TSrv in OSrv
+ */
         r = compiler->dbcopy->createNATRule();
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
@@ -414,10 +455,17 @@ bool NATCompiler_ipt::splitSDNATRule::processNext()
             }
         }
 
-        tdst=r->getTDst();
+        tdst = r->getTDst();
         tdst->clearChildren();
         tdst->setAnyElement();
 
+        if (tsrv_translates_dst_port)
+        {
+            tsrv = r->getTSrv();
+            tsrv->clearChildren();
+            tsrv->setAnyElement();
+        }
+
         tmp_queue.push_back(r);
     }
     else 
@@ -979,7 +1027,7 @@ bool NATCompiler_ipt::ReplaceFirewallObjectsTSrc::processNext()
                     if (iface->isLoopback() ||
                         iface->isUnnumbered() ||
                         iface->isBridgePort() ) continue;
-                    if (odstrel->getBool("single_object_negation") &&
+                    if (odstrel->getBool("single_object_negation") && odst_iface &&
                         odst_iface->getId()==iface->getId()) continue;
 
                     rel->addRef( *i );
@@ -2396,6 +2444,8 @@ void NATCompiler_ipt::compile()
         } else
             printRule=new PrintRule("generate iptables shell script");
 
+        printRule->setContext(this);
+        printRule->initialize();
         add( printRule );
 
         add( new simplePrintProgress() );
