@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.h 468 2008-08-14 02:07:36Z vadim $
+  $Id: OSConfigurator_linux24.h 752 2009-01-30 04:54:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -68,8 +68,9 @@ namespace fwcompiler {
 
         void registerMultiAddressObject(libfwbuilder::MultiAddressRunTime *at);
         void printChecksForRunTimeMultiAddress();
-        void printShellFunctions();
+        std::string printShellFunctions(bool no_comment);
         std::string printPathForAllTools(const std::string &os);
+        std::string printIPForwardingCommands(bool no_comment);
         void configureInterfaces();
         void printCommandsToAddVirtualAddressesForNAT();
         
