@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h 1037 2009-06-05 16:58:28Z vadim $
+  $Id: PolicyCompiler_ipt.h 1182 2009-07-19 19:17:42Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -221,6 +221,11 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(convertAnyToNotFWForShadowing);
 
+	/**
+	 * processes rules with negation in Itf if it holds only one object
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(singleItfNegation);
+
 	/**
 	 * processes rules with negation in Src if it holds only one object
 	 */
@@ -509,6 +514,15 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(specialCaseWithFW1);
 
+	/**
+	 * splits rule if firewall is in dst, interface is not empty,
+	 * direction is Outbound and chain is not OUTPUT (it makes
+	 * sense to check packets in OUTPUT chain with destination
+	 * address that belogns to the firewall, but it does not make
+	 * sense to do it in FORWARD chain)
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(specialCaseWithFWInDstAndOutbound);
+
 	/**
 	 * expands src and dst if both contain fw object. Unlike
 	 * standard processor ExpandMultipleAddresses, this one
@@ -789,6 +803,11 @@ namespace fwcompiler {
         };
         friend class PolicyCompiler_ipt::optimize3;
 
+	/**
+	 * Optimize rules by dropping "-i +" or "-o +" if chain is
+         * INPUT or OUTPUT respectively.
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(optimizeForMinusIOPlus);
 
 	/**
 	 * split rules so multiport module can be used
@@ -876,8 +895,20 @@ namespace fwcompiler {
             bool minus_n_tracker_initialized;
             bool have_m_iprange;
             std::string current_rule_label;
+            std::string version;
 
-            void InitializeMinusNTracker();
+            void initializeMinusNTracker();
+
+            /*
+             * Prints single --option with argument and negation "!"
+             * taking into account the change that happened in iptables 1.4.3.1
+             * that causes warning
+             * Using intrapositioned negation (`--option ! this`) is deprecated in favor of extrapositioned (`! --option this`).
+             */
+            virtual std::string _printSingleOptionWithNegation(
+                const std::string &option,
+                libfwbuilder::RuleElement *rel,
+                const std::string &arg);
             
             virtual std::string _createChain(const std::string &chain);
             virtual std::string _printRuleLabel(libfwbuilder::PolicyRule *r);
@@ -925,6 +956,8 @@ namespace fwcompiler {
             public:
 
             PrintRule(const std::string &name);
+            void initialize();
+
             virtual std::string _printGlobalLogParameters();
             virtual std::string _printOptionalGlobalRules();
             virtual std::string _declareTable();
