@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt_optimizer.cpp 800 2009-04-11 00:53:50Z vadim $
+  $Id: PolicyCompiler_ipt_optimizer.cpp 1210 2009-07-27 05:34:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -297,6 +297,7 @@ bool PolicyCompiler_ipt::optimize3::processNext()
     {
         printRule = new PrintRule("");
         printRule->setContext(compiler);
+        printRule->initialize();
     }
     string thisRule = rule->getLabel() + " " + printRule->PolicyRuleToString(rule);
     if (rules_seen_so_far.count(thisRule)!=0) return true;
@@ -306,3 +307,25 @@ bool PolicyCompiler_ipt::optimize3::processNext()
 
     return true;
 }
+
+bool PolicyCompiler_ipt::optimizeForMinusIOPlus::processNext()
+{
+    PolicyRule *rule;
+    rule=getNext(); if (rule==NULL) return false;
+
+    string iface_name = rule->getInterfaceStr();
+    if (iface_name.empty() || iface_name=="nil" )
+    {
+        tmp_queue.push_back(rule);
+        return true;
+    }
+
+    string chain = rule->getStr("ipt_chain");
+
+    if (iface_name == "*" && (chain == "INPUT" || chain == "OUTPUT"))
+        rule->setInterfaceStr("");
+
+    tmp_queue.push_back(rule);
+    return true;
+}
+
