@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipt.cpp 816 2009-04-23 17:50:20Z vadim $
+  $Id: ipt.cpp 1153 2009-07-13 23:14:55Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -773,6 +773,13 @@ int main(int argc, char **argv)
             }
         }
 
+        if (fw->getOptionsObject()->getStr("prolog_place") == "after_flush" &&
+            fw->getOptionsObject()->getBool("use_iptables_restore"))
+        {
+            throw FWException("Prolog place \"after policy reset\" can not be used"
+                              " when policy is activated with iptables-restore");
+        }
+
 	string firewall_dir = options->getStr("firewall_dir");
 	if (firewall_dir=="") firewall_dir="/etc";
 
