@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: pf.cpp 585 2008-10-09 05:08:41Z vadim $
+  $Id: pf.cpp 791 2009-03-24 16:01:23Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -433,8 +433,8 @@ void printStaticOptions(ofstream &file, Firewall* fw)
     //file << table_factory->PrintTables();
     //file << endl;
 
-    if (prolog_place == "pf_file_after_tables")
-        printProlog(file, pre_hook);
+    //if (prolog_place == "pf_file_after_tables")
+    //    printProlog(file, pre_hook);
 
 }
 
@@ -679,16 +679,15 @@ int main(int argc, char * const *argv)
           ]->Resources::getResourceStr("/FWBuilderResources/Target/family");
 
 	if (family=="solaris")
-            oscnf=new OSConfigurator_solaris(objdb , fwobjectname, false);
+            oscnf = new OSConfigurator_solaris(objdb , fwobjectname, false);
 
 	if (family=="openbsd")
         {
-            cerr << "Calling OSConfigurator_openbsd" << endl;
-            oscnf=new OSConfigurator_openbsd(objdb , fwobjectname, false);
+            oscnf = new OSConfigurator_openbsd(objdb , fwobjectname, false);
         }
 
 	if (family=="freebsd")
-            oscnf=new OSConfigurator_freebsd(objdb , fwobjectname, false);
+            oscnf = new OSConfigurator_freebsd(objdb , fwobjectname, false);
 
 	if (oscnf==NULL)
 	    throw FWException(_("Unrecognized host OS ") + 
@@ -701,7 +700,7 @@ int main(int argc, char * const *argv)
 
         findImportedRuleSets(fw, all_policies);
 
-        vector<bool> ipv4_6_runs;
+        vector<int> ipv4_6_runs;
         bool have_nat = false;
         bool have_pf = false;
 
@@ -713,22 +712,23 @@ int main(int argc, char * const *argv)
         if (options->getStr("ipv4_6_order").empty() ||
             options->getStr("ipv4_6_order") == "ipv4_first")
         {
-            if (ipv4_run) ipv4_6_runs.push_back(false);
-            if (ipv6_run) ipv4_6_runs.push_back(true);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
         }
 
         if (options->getStr("ipv4_6_order") == "ipv6_first")
         {
-            if (ipv6_run) ipv4_6_runs.push_back(true);
-            if (ipv4_run) ipv4_6_runs.push_back(false);
+            if (ipv6_run) ipv4_6_runs.push_back(AF_INET6);
+            if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
         }
 
         ostringstream *main_str = new ostringstream();
 
-        for (vector<bool>::iterator i=ipv4_6_runs.begin(); 
+        for (vector<int>::iterator i=ipv4_6_runs.begin();
              i!=ipv4_6_runs.end(); ++i)
         {
-            bool ipv6_policy = *i;
+            int policy_af = *i;
+            bool ipv6_policy = (policy_af == AF_INET6);
 
             // Count rules for each address family
             int nat_count = 0;
@@ -738,14 +738,14 @@ int main(int argc, char * const *argv)
                  p!=all_nat.end(); ++p)
             {
                 NAT *nat = NAT::cast(*p);
-                if (nat->isV6()==ipv6_policy) nat_count++;
+                if (nat->matchingAddressFamily(policy_af)) nat_count++;
             }
 
             for (list<FWObject*>::iterator p=all_policies.begin();
                  p!=all_policies.end(); ++p)
             {
                 Policy *policy = Policy::cast(*p);
-                if (policy->isV6()==ipv6_policy) policy_count++;
+                if (policy->matchingAddressFamily(policy_af)) policy_count++;
             }
 
             if (nat_count || policy_count)
@@ -763,7 +763,7 @@ int main(int argc, char * const *argv)
             {
                 NAT *nat = NAT::cast(*p);
 
-                if (nat->isV6()!=ipv6_policy) continue;
+                if (!nat->matchingAddressFamily(policy_af)) continue;
 
                 string ruleset_name = nat->getName();
                 if (nat->isTop())
@@ -825,10 +825,20 @@ int main(int argc, char * const *argv)
                  p!=all_policies.end(); ++p )
             {
                 Policy *policy = Policy::cast(*p);
-
-                if (policy->isV6()!=ipv6_policy) continue;
-
                 string ruleset_name = policy->getName();
+
+                if (ruleset_name.find("/*")!=string::npos)
+                {
+                    cout << "The name of the policy ruleset "
+                         << ruleset_name
+                         << " ends with '/*', assuming it is externally"
+                         << " controlled and skipping it."
+                         << endl;
+                    continue;
+                }
+
+                if (!policy->matchingAddressFamily(policy_af)) continue;
+
                 if (policy->isTop())
                     ruleset_name = "__main__";
 
@@ -892,6 +902,8 @@ int main(int argc, char * const *argv)
             string file_name = output_dir + conf_files[ruleset_name];
             ostringstream *strm = fi->second;
 
+            if (ruleset_name.find("/*")!=string::npos) continue;
+
             ofstream pf_file;
             pf_file.exceptions(
                 ofstream::eofbit|ofstream::failbit|ofstream::badbit);
@@ -905,10 +917,20 @@ int main(int argc, char * const *argv)
             if (ruleset_name == "__main__")
             {
                 printStaticOptions(pf_file, fw);
+
+                pf_file << table_factories[ruleset_name]->PrintTables();
+
+                if (prolog_place == "pf_file_after_tables")
+                    printProlog(pf_file, pre_hook);
+            } else 
+            {
+                pf_file << table_factories[ruleset_name]->PrintTables();
             }
-            pf_file << table_factories[ruleset_name]->PrintTables();
+
             pf_file << strm->str();
             pf_file.close();
+
+
         }
 
         char          *timestr;
@@ -1009,6 +1031,10 @@ int main(int argc, char * const *argv)
                         << " || exit 1"
                         << endl;
         }
+
+        if (options->getBool("pf_flush_states") && fw->getStr("version")=="4.x")
+            fw_file << "$PFCTL -F states" << endl;
+
         fw_file << endl;
         fw_file << "#" << endl;
         fw_file << "# Epilog script" << endl;
