@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: NATCompiler_ipf.cpp 709 2008-12-25 20:38:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -163,8 +163,7 @@ bool NATCompiler_ipf::ExpandPortRange::processNext()
 
         for (int p=rs; p<=re; ++p)
         {
-            NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME) );
+            NATRule *r = compiler->dbcopy->createNATRule();
             r->duplicate(rule);
 
             FWObject *newSrv = compiler->dbcopy->create(newSrvType);
@@ -252,8 +251,7 @@ bool NATCompiler_ipf::AssignInterface::processNext()
                  iface->isBridgePort() || 
                  iface->isLoopback()) continue;
 
-            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) 
-);
+            NATRule *r= compiler->dbcopy->createNATRule();
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             r->setInterfaceId( iface->getId() );
@@ -290,8 +288,7 @@ bool NATCompiler_ipf::AssignInterface::processNext()
                 iface->isUnnumbered() ||
                 iface->isBridgePort()) continue;
 
-            NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME) );
+            NATRule *r = compiler->dbcopy->createNATRule();
             r->duplicate(rule);
             compiler->temp_ruleset->add(r);
 
@@ -333,7 +330,7 @@ bool NATCompiler_ipf::prepareForLB::processNext()
                 cl.push_back(o);
                 if (cl.size()==2)
                 {
-                    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
+                    NATRule *r= compiler->dbcopy->createNATRule();
                     compiler->temp_ruleset->add(r);
                     r->duplicate(rule);
                     RuleElementTDst *notdst=r->getTDst();
@@ -347,7 +344,7 @@ bool NATCompiler_ipf::prepareForLB::processNext()
 
             if (cl.size()!=0)
             {
-                NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
+                NATRule *r= compiler->dbcopy->createNATRule();
                 compiler->temp_ruleset->add(r);
                 r->duplicate(rule);
                 RuleElementTDst *notdst=r->getTDst();
@@ -489,8 +486,7 @@ bool NATCompiler_ipf::expandAnyService::processNext()
 
     if (rule->getRuleType()==NATRule::SNAT && srv->isAny())
     {
-	NATRule *r= NATRule::cast(
-	    compiler->dbcopy->create(NATRule::TYPENAME) );
+	NATRule *r= compiler->dbcopy->createNATRule();
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         r->setBool("needs_portmap",true);
