@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf_writers.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: NATCompiler_ipf_writers.cpp 714 2008-12-28 21:06:00Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,6 +33,7 @@
 #include "fwbuilder/ICMPService.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
+#include "fwbuilder/CustomService.h"
 #include "fwbuilder/Host.h"
 #include "fwbuilder/Network.h"
 #include "fwbuilder/Interface.h"
@@ -181,10 +182,17 @@ void NATCompiler_ipf::PrintRule::_printAddr_R_LB(RuleElementTDst *tdst)
     compiler->output << " ";
 }
 
-
-
 void NATCompiler_ipf::PrintRule::_printProtocol(Service *srv)
 {
+    if ( CustomService::isA(srv) )
+    {
+        // CustomService returns protocol name starting with v3.0.4
+        // However CustomService can return protocol name "any", which we should
+        // just skip.
+        string pn = srv->getProtocolName();
+        if (pn == "any") return;
+    }
+
     compiler->output << srv->getProtocolName() << " ";
 }
 
