@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf_writers.cpp,v 1.11 2007/05/08 00:22:58 vkurland Exp $
+  $Id: PolicyCompiler_ipf_writers.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -267,9 +267,6 @@ void PolicyCompiler_ipf::PrintRule::_printAddr(Address  *o,bool neg)
         assert(atrt==NULL);
     }
 
-    IPAddress addr=o->getAddress();
-    Netmask   mask=o->getNetmask();
-
     if (options->getBool("dynAddr") &&
         Interface::cast(o)!=NULL && Interface::cast(o)->isDyn()) 
     {
@@ -278,23 +275,36 @@ void PolicyCompiler_ipf::PrintRule::_printAddr(Address  *o,bool neg)
         return;
     }
 
-    if (Interface::cast(o)!=NULL) {
-	mask=Netmask("255.255.255.255");
+    const InetAddr *addr = o->getAddressPtr();
+    if (Interface::cast(o)!=NULL && addr==NULL)
+    {
+        compiler->output << "<thishost> ";
     }
+    if (addr)
+    {
+        InetAddr mask = *(o->getNetmaskPtr());
 
-    if (IPv4::cast(o)!=NULL) {
-	mask=Netmask("255.255.255.255");
-    }
+        if (Interface::cast(o)!=NULL) {
+            mask = InetAddr(InetAddr::getAllOnes());
+        }
 
-    if (addr.toString()=="0.0.0.0" && mask.toString()=="0.0.0.0") {
-	compiler->output << "any ";
-    } else {	
-	if (neg) compiler->output << "! ";
-	compiler->output << addr.toString();
-	if (mask.toString()!="255.255.255.255") {
-	    compiler->output << "/" << mask.getLength();
-	}
-	compiler->output << " ";
+        if (o->dimension()==1)
+        {
+            mask = InetAddr(InetAddr::getAllOnes());
+        }
+
+        if (addr->isAny() && mask.isAny())
+        {
+            compiler->output << "any ";
+        } else {	
+            if (neg) compiler->output << "! ";
+            compiler->output << addr->toString();
+            if (!mask.isHostMask())
+            {
+                compiler->output << "/" << mask.getLength();
+            }
+            compiler->output << " ";
+        }
     }
 }
 
