@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp 1047 2009-06-08 21:43:16Z vadim $
+  $Id: PolicyCompiler_pf.cpp 1359 2009-08-27 17:10:20Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -376,9 +376,15 @@ bool PolicyCompiler_pf::fillDirection::processNext()
             compiler->complexMatch(compiler->fw, dst)) return true;
 
         if (!src->isAny() && compiler->complexMatch(compiler->fw, src))
+        {
             rule->setDirection( PolicyRule::Outbound );
+            compiler->warning("Changing rule direction due to self reference in rule "+rule->getLabel());
+        }
         if (!dst->isAny() && compiler->complexMatch(compiler->fw, dst))
+        {
             rule->setDirection( PolicyRule::Inbound );
+            compiler->warning("Changing rule direction due to self reference in rule "+rule->getLabel());
+        }
     }
     return true;
 }
@@ -515,7 +521,8 @@ bool PolicyCompiler_pf::SplitDirection::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
-    if (rule->getDirection()==PolicyRule::Both)
+    if (rule->getDirection()==PolicyRule::Both &&
+        rule->getAction()==PolicyRule::Route)
     {
 	PolicyRule *r= compiler->dbcopy->createPolicyRule();
 	compiler->temp_ruleset->add(r);
@@ -1071,7 +1078,12 @@ void PolicyCompiler_pf::compile()
 	add( new splitIfFirewallInSrc("split rule if firewall is in Src"   ));
 	add( new splitIfFirewallInDst("split rule if firewall is in Dst"   ));
 	add( new fillDirection("determine directions"               ));
+
+// commented out for bug #2828602
+// ... and put back per #2844561
+// both bug reports/patches are by Tom Judge (tomjudge on sourceforge)
 	add( new SplitDirection("split rules with direction 'both'"  ));
+
         add( new addLoopbackForRedirect(
                  "add loopback to rules that permit redirected services" ) );
 	add( new ExpandMultipleAddresses(
