@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp 1037 2009-06-05 16:58:28Z vadim $
+  $Id: PolicyCompiler_pf_writers.cpp 1302 2009-08-10 22:33:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -147,22 +147,27 @@ void PolicyCompiler_pf::PrintRule::_printRouteOptions(PolicyRule *rule)
     if (rule->getAction() == PolicyRule::Route)
     {
 	string prefix = "pf";
-	if (compiler->myPlatformName()=="ipf")
-		prefix="ipf";
+	if (compiler->myPlatformName()=="ipf") prefix="ipf";
+
 	string ro = ruleopt->getStr(prefix+"_route_option");
         if (ruleopt->getBool("pf_fastroute") && ro != "none")
 	{
-            compiler->abort("Cannot use fastroute and route method in same rule they are mutually exclusive in rule "+rule->getLabel());
-	} else if (ruleopt->getBool("pf_fastroute") && ro == "none" ) {
+            compiler->abort("Cannot use fastroute and route method in "
+                            "the same rule because they are mutually "
+                            "exclusive. Rule " + rule->getLabel());
+	} else if (ruleopt->getBool("pf_fastroute") && ro == "none")
+        {
             compiler->output << "fastroute ";
-	} else {
+	} else
+        {
             string roif = ruleopt->getStr(prefix+"_route_opt_if");
             string roaddr_list = ruleopt->getStr(prefix+"_route_opt_addr");
             string roload = ruleopt->getStr("pf_route_load_option");
             if (!ro.empty())
             {
                 if (roif.empty())
-                    compiler->abort("Interface specification is required for action Route in rule "+rule->getLabel());
+                    compiler->abort("Interface specification is required "
+                                    "for action Route. Rule " + rule->getLabel());
 
                 if (ro == "route_through")
                     compiler->output << "route-to ";
@@ -334,8 +339,8 @@ void PolicyCompiler_pf::PrintRule::_printTag(PolicyRule *rule)
 
 void PolicyCompiler_pf::PrintRule::_printDirection(PolicyRule *rule)
 {
-    if (rule->getDirection()==PolicyRule::Outbound)  compiler->output << "out "; 
-    else	                                     compiler->output << "in  "; 
+    if (rule->getDirection()==PolicyRule::Outbound) compiler->output << "out ";
+    if (rule->getDirection()==PolicyRule::Inbound) compiler->output << "in  ";
 }
 
 void PolicyCompiler_pf::PrintRule::_printLogging(PolicyRule *rule)
@@ -949,9 +954,12 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 	    compiler->output << "synproxy state ";
         else
         {
-            if (compiler->getCachedFwOpt()->getBool("pf_modulate_state") && tcpsrv!=NULL)
+            if ((ruleopt->getBool("pf_modulate_state") || 
+                 compiler->getCachedFwOpt()->getBool("pf_modulate_state")) &&
+                tcpsrv!=NULL) 
+            {
                 compiler->output << "modulate state ";
-            else
+            } else
             {
                 /*
                  * "flags S/SA keep state" is implicit in 4.x
