@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pix.cpp,v 1.1 2008/03/06 06:48:59 vkurland Exp $
+  $Id: NATCompiler_pix.cpp 547 2008-09-21 10:32:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -36,7 +36,7 @@
 #include "fwbuilder/UDPService.h"
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/IPv4.h"
-#include "fwbuilder/IPAddress.h"
+#include "fwbuilder/InetAddr.h"
 #include "fwbuilder/Network.h"
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/AddressTable.h"
@@ -44,6 +44,7 @@
 #include <algorithm>
 #include <functional>
 #include <iostream>
+#include <cstring>
 #include <assert.h>
 
 using namespace libfwbuilder;
@@ -54,8 +55,9 @@ string NATCompiler_pix::myPlatformName() { return "pix"; }
 
 NATCompiler_pix::NATCompiler_pix(FWObjectDatabase *_db,
                                  const std::string &fwname,
+                                 bool ipv6_policy,
                                  OSConfigurator *_oscnf) : 
-    NATCompiler(_db,fwname,_oscnf) , helper(this)
+    NATCompiler(_db, fwname, ipv6_policy, _oscnf) , helper(this)
 { 
 }
 
@@ -103,8 +105,8 @@ string NATCompiler_pix::debugPrintRule(Rule *r)
 {
     NATRule *rule=NATRule::cast(r);
 
-    Interface *iface1 = getCachedFwInterface( rule->getStr("nat_iface_orig") );
-    Interface *iface2 = getCachedFwInterface( rule->getStr("nat_iface_trn")  );
+    Interface *iface1 = getCachedFwInterface( rule->getInt("nat_iface_orig") );
+    Interface *iface2 = getCachedFwInterface( rule->getInt("nat_iface_trn")  );
     string iface1_name=(iface1!=NULL)?iface1->getName():"";
     string iface2_name=(iface2!=NULL)?iface2->getName():"";
 
@@ -113,6 +115,7 @@ string NATCompiler_pix::debugPrintRule(Rule *r)
     switch (rule->getRuleType()) 
     {
     case NATRule::NONAT:
+        os << "NONAT Type: " << rule->getInt("nonat_type");
         break;
 
     case NATRule::SNAT:
@@ -125,18 +128,20 @@ string NATCompiler_pix::debugPrintRule(Rule *r)
             os << " rule=[" << natcmd->rule_label << "]";
             os << " id=" << natcmd->nat_id;
             os << " rule=" << natcmd->rule_label;
-            os << " nat_acl_name="   <<  natcmd->nat_acl_name;
+            os << " nat_acl_name=" << natcmd->nat_acl_name;
             os << " (" << nat_acl_names[natcmd->nat_acl_name] << ")";
-            os << " o_src="          <<  natcmd->o_src->getAddress().toString();
-            os << " o_dst="          <<  natcmd->o_dst->getAddress().toString();
-            os << " o_srv="          <<  natcmd->o_srv->getName();
-            os << " o_iface="        <<  natcmd->o_iface->getLabel();
-            os << " t_addr="         <<  natcmd->t_addr->getAddress().toString();
-            os << " t_iface="        <<  natcmd->t_iface->getLabel();
-            os << " ignore_global="  <<  string((natcmd->ignore_global)?"1":"0");
-            os << " ignore_nat="     <<  string((natcmd->ignore_nat)?"1":"0");
-            os << " ignore_nat_and_print_acl=" << string((natcmd->ignore_nat_and_print_acl)?"1":"0");
-            os << " use_nat_0_0="    <<  string((rule->getBool("use_nat_0_0"))?"1":"0");
+            os << " o_src=" <<  natcmd->o_src->getAddressPtr()->toString();
+            os << " o_dst=" <<  natcmd->o_dst->getAddressPtr()->toString();
+            os << " o_srv=" <<  natcmd->o_srv->getName();
+            os << " o_iface=" <<  natcmd->o_iface->getLabel();
+            os << " t_addr=" <<  natcmd->t_addr->getAddressPtr()->toString();
+            os << " t_iface=" <<  natcmd->t_iface->getLabel();
+            os << " ignore_global=" << string((natcmd->ignore_global)?"1":"0");
+            os << " ignore_nat=" << string((natcmd->ignore_nat)?"1":"0");
+            os << " ignore_nat_and_print_acl="
+               << string((natcmd->ignore_nat_and_print_acl)?"1":"0");
+            os << " use_nat_0_0="
+               << string((rule->getBool("use_nat_0_0"))?"1":"0");
         }
     }
     break;
@@ -150,9 +155,9 @@ string NATCompiler_pix::debugPrintRule(Rule *r)
             os << " StaticCmd:";
             os << " acl=" << scmd->acl_name;
             os << " (" << nat_acl_names[scmd->acl_name] << ")";
-            os << " iaddr=" << scmd->iaddr->getAddress().toString();
-            os << " oaddr=" << scmd->oaddr->getAddress().toString();
-            os << " osrc=" << scmd->osrc->getAddress().toString();
+            os << " iaddr=" << scmd->iaddr->getAddressPtr()->toString();
+            os << " oaddr=" << scmd->oaddr->getAddressPtr()->toString();
+            os << " osrc=" << scmd->osrc->getAddressPtr()->toString();
             os << " osrv=" << scmd->osrv->getName();
             os << " tsrv=" << scmd->tsrv->getName();
         }
@@ -203,9 +208,9 @@ list<triplet> NATCompiler_pix::findDNATForAddress(Address *src,
             Address  *tdst=getFirstTDst(rule);  assert(tdst);
             Service  *tsrv=getFirstTSrv(rule);  assert(tsrv);
 
-            if (src->getAddress()==osrc->getAddress() &&
+            if (*(src->getAddressPtr()) == *(osrc->getAddressPtr()) &&
                 (osrv->isAny() || srv->getId()==tsrv->getId()) &&
-                dst->getAddress()==tdst->getAddress())
+                *(dst->getAddressPtr()) == *(tdst->getAddressPtr()))
             {
                 if (osrv->isAny())
                 {
@@ -302,7 +307,7 @@ bool NATCompiler_pix::VerifyRules::processNext()
         Network *a1=Network::cast(compiler->getFirstOSrc(rule));
         Network *a2=Network::cast(compiler->getFirstTSrc(rule));
         if ( a1==NULL || a2==NULL ||
-             a1->getNetmask().getLength()!=a2->getNetmask().getLength() )
+             a1->getNetmaskPtr()->getLength()!=a2->getNetmaskPtr()->getLength() )
             compiler->abort("Original and translated source should both be networks of the same size . Rule "+rule->getLabel());
     }
 
@@ -311,7 +316,7 @@ bool NATCompiler_pix::VerifyRules::processNext()
         Network *a1=Network::cast(compiler->getFirstODst(rule));
         Network *a2=Network::cast(compiler->getFirstTDst(rule));
         if ( a1==NULL || a2==NULL ||
-             a1->getNetmask().getLength()!=a2->getNetmask().getLength() )
+             a1->getNetmaskPtr()->getLength()!=a2->getNetmaskPtr()->getLength() )
             compiler->abort("Original and translated destination should both be networks of the same size . Rule "+rule->getLabel());
     }
 
@@ -346,15 +351,20 @@ bool NATCompiler_pix::AssignInterface::processNext()
 
     assert(a1!=NULL && a2!=NULL);
 
-    rule->setStr("nat_iface_orig",helper.findInterfaceByNetzone(a1));
-    rule->setStr("nat_iface_trn", helper.findInterfaceByNetzone(a2));
+    rule->setInt("nat_iface_orig", helper.findInterfaceByNetzone(a1));
+    rule->setInt("nat_iface_trn",  helper.findInterfaceByNetzone(a2));
 
-    if ( rule->getStr("nat_iface_orig")=="" ) 
-	compiler->abort("Object '"+a1->getName()+"' does not belong to any known network zone. Rule: "+rule->getLabel());
-    if ( rule->getStr("nat_iface_trn")=="" ) 
-	compiler->abort("Object '"+a2->getName()+"' does not belong to any known network zone. Rule: "+rule->getLabel());
+    if ( rule->getInt("nat_iface_orig")==-1 ) 
+	compiler->abort("Object '" + a1->getName() + 
+                        "' does not belong to any known network zone. Rule: " +
+                        rule->getLabel());
 
-//    if ( rule->getStr("nat_iface_orig")==rule->getStr("nat_iface_trn"))
+    if ( rule->getInt("nat_iface_trn")==-1 ) 
+	compiler->abort("Object '" + a2->getName() + 
+                        "' does not belong to any known network zone. Rule: " + 
+                        rule->getLabel());
+
+//    if ( rule->getInt("nat_iface_orig")==rule->getInt("nat_iface_trn"))
 //	compiler->abort("Objects '"+a1->getName()+"' and '"+a2->getName()+"' belong to the same network zone. Can not build NAT configuration. Rule: "+rule->getLabel());
 
     return true;
@@ -366,15 +376,19 @@ bool NATCompiler_pix::verifyInterfaces::processNext()
     tmp_queue.push_back(rule);
 
 #ifdef WRONG_CHECK
-    if ( rule->getStr("nat_iface_orig")!=rule->getStr("nat_iface_trn") )
+    if ( rule->getInt("nat_iface_orig")!=rule->getInt("nat_iface_trn") )
     {
-	if (rule->getRuleType()==NATRule::SNAT) {
+	if (rule->getRuleType()==NATRule::SNAT)
+        {
 	    Interface *iface1=
-		Interface::cast( rule->getRoot()->findInIndex(rule->getStr("nat_iface_orig")) );
+		Interface::cast( rule->getRoot()->findInIndex(
+                                     rule->getInt("nat_iface_orig")) );
 	    Interface *iface2=
-		Interface::cast( rule->getRoot()->findInIndex(rule->getStr("nat_iface_trn")) );
+		Interface::cast( rule->getRoot()->findInIndex(
+                                     rule->getInt("nat_iface_trn")) );
 
-	    if ( iface1->getSecurityLevel() <= iface2->getSecurityLevel() ) {
+	    if ( iface1->getSecurityLevel() <= iface2->getSecurityLevel() )
+            {
 		char lvl1[32];
 		char lvl2[32];
 		sprintf(lvl1,"%d",iface1->getSecurityLevel());
@@ -405,52 +419,62 @@ bool NATCompiler_pix::verifyRuleElements::processNext()
     Address  *tdst=compiler->getFirstTDst(rule);  assert(tdst);
     Service  *tsrv=compiler->getFirstTSrv(rule);  assert(tsrv);
 
-    bool      version_lt_63=libfwbuilder::XMLTools::version_compare(compiler->fw->getStr("version"),"6.3")<0;
+    bool version_lt_63 = libfwbuilder::XMLTools::version_compare(
+        compiler->fw->getStr("version"),"6.3")<0;
 
     if (rule->getRuleType()==NATRule::SNAT)
     {
 	if ((! osrv->isAny() || ! tsrv->isAny()) && version_lt_63)
-	    compiler->abort("only PIX v6.3 recognizes services in global NAT. Rule: "+rule->getLabel() );
+	    compiler->abort("only PIX v6.3 recognizes services in global NAT. "
+                            "Rule: "+rule->getLabel() );
     }
 
     if (rule->getRuleType()==NATRule::DNAT)
     {
 	if (AddressRange::cast(odst) || AddressRange::cast(tdst)) 
 	    compiler->abort(
-		"Address ranges are not supported in original destination or translated destination in NAT rule "+rule->getLabel() );
+		"Address ranges are not supported in original destination or "
+                "translated destination in NAT rule "+rule->getLabel() );
 
 	if (Network::isA(odst) && Network::isA(tdst))
         {
-            Netmask n1=(Interface::cast(odst))?Netmask("255.255.255.255"):odst->getNetmask();
-            Netmask n2=(Interface::cast(tdst))?Netmask("255.255.255.255"):tdst->getNetmask();
+            InetAddr n1 = (Interface::cast(odst)) ? 
+                InetAddr(InetAddr::getAllOnes()) : (*(odst->getNetmaskPtr()));
+            InetAddr n2 = (Interface::cast(tdst)) ? 
+                InetAddr(InetAddr::getAllOnes()) : (*(tdst->getNetmaskPtr()));
 
             if ( !(n1==n2) )
                 compiler->abort(
-                    "Original and translated destination must be of the same size in the NAT rule "+rule->getLabel());
+                    "Original and translated destination must be of the same "
+                    "size in the NAT rule "+rule->getLabel());
         }
 
 
 	if (osrv->getTypeName()!=tsrv->getTypeName()) 
-	    compiler->abort("Original and translated services must be of the same type. Rule: "+rule->getLabel());
+	    compiler->abort("Original and translated services must be of "
+                            "the same type. Rule: "+rule->getLabel());
 
 	if (ICMPService::isA(osrv))
-	    compiler->abort("ICMP services are not supported in static NAT. Rule: "+rule->getLabel());
+	    compiler->abort("ICMP services are not supported in static NAT. "
+                            "Rule: "+rule->getLabel());
 
 	if (TCPService::isA(osrv) || UDPService::isA(osrv))
         {
-	    int drs=osrv->getInt("dst_range_start");
-	    int dre=osrv->getInt("dst_range_end");
+	    int drs=TCPUDPService::cast(osrv)->getDstRangeStart();
+	    int dre=TCPUDPService::cast(osrv)->getDstRangeEnd();
 
 	    if (drs!=dre)
-		compiler->abort("TCP or UDP service with a port range is not supported in NAT. Rule "+rule->getLabel());
+		compiler->abort("TCP or UDP service with a port range is not "
+                                "supported in NAT. Rule "+rule->getLabel());
 	}
 	if (TCPService::isA(tsrv) || UDPService::isA(tsrv))
         {
-	    int drs=tsrv->getInt("dst_range_start");
-	    int dre=tsrv->getInt("dst_range_end");
+	    int drs=TCPUDPService::cast(tsrv)->getDstRangeStart();
+	    int dre=TCPUDPService::cast(tsrv)->getDstRangeEnd();
 
 	    if (drs!=dre)
-		compiler->abort("TCP or UDP service with a port range is not supported in NAT. Rule "+rule->getLabel());
+		compiler->abort("TCP or UDP service with a port range is not "
+                                "supported in NAT. Rule "+rule->getLabel());
 	}
     }
 
@@ -644,16 +668,19 @@ void NATCompiler_pix::UseFirewallInterfaces::scanInterfaces(RuleElement *rel)
                         " ( found object with type "+
                         string((o!=NULL)?o->getTypeName():"<NULL>") +
                         ")");
+    const InetAddr *obj_addr = obj->getAddressPtr();
+    if (obj_addr==NULL) return;
 
     list<FWObject*> l2=compiler->fw->getByType(Interface::TYPENAME);
     for (list<FWObject*>::iterator i=l2.begin(); i!=l2.end(); ++i)
     {
-        Interface *interface_=Interface::cast(*i);
-
-        if (interface_->getAddress()==obj->getAddress()) 
+        Interface *iface=Interface::cast(*i);
+        const InetAddr *iface_addr = iface->getAddressPtr();
+        if (iface_addr == NULL) continue;
+        if (*iface_addr == *obj_addr)
         {
             rel->removeRef(obj);
-            rel->addRef(interface_);
+            rel->addRef(iface);
             return;
         }        
     }
@@ -700,20 +727,21 @@ bool NATCompiler_pix::processNONATRules::processNext()
  */
         if (osrc_level>odst_level)
         {
-            rule->setInt("nonat_type",NONAT_NAT0);
+            rule->setInt("nonat_type", NONAT_NAT0);
             nonat n0;
-            n0.i_iface=osrc_iface;
-            n0.o_iface=odst_iface;
-            n0.src=osrc;
-            n0.dst=odst;
-            n0.acl_name="nat0."+osrc_iface->getLabel();
-            n0.last=true;
+            n0.i_iface = osrc_iface;
+            n0.o_iface = odst_iface;
+            n0.src = osrc;
+            n0.dst = odst;
+            n0.acl_name = "nat0."+osrc_iface->getLabel();
+            n0.last = true;
 
-            pix_comp->nonat_rules[rule->getId()]= n0;
+            pix_comp->nonat_rules[rule->getId()] = n0;
             pix_comp->registerACL(n0.acl_name);
 
-            if ( pix_comp->first_nonat_rule_id[osrc_iface->getId()].empty() ) 
-                pix_comp->first_nonat_rule_id[osrc_iface->getId()]=rule->getId();
+            if (pix_comp->first_nonat_rule_id.count(osrc_iface->getId()) == 0)
+                pix_comp->first_nonat_rule_id[osrc_iface->getId()] =
+                    rule->getId();
             
         } else
         {
@@ -746,9 +774,11 @@ bool NATCompiler_pix::createNATCmd::processNext()
         natcmd->o_src   = osrc;
         natcmd->o_dst   = odst;
         natcmd->o_srv   = osrv;
-        natcmd->o_iface = compiler->getCachedFwInterface( rule->getStr("nat_iface_orig") );
+        natcmd->o_iface = compiler->getCachedFwInterface(
+            rule->getInt("nat_iface_orig") );
         natcmd->t_addr  = tsrc;
-        natcmd->t_iface = compiler->getCachedFwInterface( rule->getStr("nat_iface_trn" ) );
+        natcmd->t_iface = compiler->getCachedFwInterface(
+            rule->getInt("nat_iface_trn" ) );
 
         natcmd->nat_acl_name = pix_comp->getNATACLname(rule,"");
         pix_comp->registerACL(natcmd->nat_acl_name);
@@ -766,7 +796,8 @@ bool NATCompiler_pix::createNATCmd::processNext()
             }
         }
 
-        natcmd->ignore_nat=natcmd->ignore_nat_and_print_acl=natcmd->ignore_global=false;
+        natcmd->ignore_nat = natcmd->ignore_nat_and_print_acl =
+            natcmd->ignore_global=false;
         natcmd->use_nat_0_0 = rule->getBool("use_nat_0_0");
         
 /*
@@ -846,12 +877,13 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
 
         if (rule->getRuleType()==NATRule::DNAT)
         {
-            StaticCmd *scmd=pix_comp->static_commands[rule->getInt("sc_cmd")];
+            StaticCmd *scmd = pix_comp->static_commands[rule->getInt("sc_cmd")];
 
-            for (map<int,StaticCmd*>::iterator i1=pix_comp->static_commands.begin();
+            map<int,StaticCmd*>::iterator i1;
+            for (i1=pix_comp->static_commands.begin();
                  i1!=pix_comp->static_commands.end(); ++i1) 
             {
-                StaticCmd *sc=(*i1).second;
+                StaticCmd *sc = (*i1).second;
                 if (scmd==sc) break;
                 
                 if (*(scmd->oaddr) == *(sc->oaddr) &&
@@ -872,27 +904,30 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
 
 	if (rule->getRuleType()==NATRule::SNAT) 
         { 
-            NATCmd *natcmd=pix_comp->nat_commands[ rule->getInt("nat_cmd") ];
+            NATCmd *natcmd = pix_comp->nat_commands[ rule->getInt("nat_cmd") ];
 
-            for (map<int,NATCmd*>::iterator i1=pix_comp->nat_commands.begin();
-                 i1!=pix_comp->nat_commands.end(); ++i1) 
+            map<int,NATCmd*>::iterator i1;
+            for (i1 = pix_comp->nat_commands.begin();
+                 i1 != pix_comp->nat_commands.end(); ++i1) 
             {
-                NATCmd *nc=(*i1).second;
+                NATCmd *nc = (*i1).second;
 /* since map nat_commands is sorted by the key, we only have to scan it
  * until we hit natcmd 
  */
                 if (natcmd==nc) break;
 
-                IPAddress  a1=natcmd->t_addr->getAddress();
-                IPAddress  a2=nc->t_addr->getAddress();
+                const InetAddr *a1 = natcmd->t_addr->getAddressPtr();
+                const InetAddr *a2 = nc->t_addr->getAddressPtr();
 
-                Interface *int1=natcmd->t_iface;
-                Interface *int2=nc->t_iface;
+                Interface *int1 = natcmd->t_iface;
+                Interface *int2 = nc->t_iface;
 
-                if ( a1 == a2 && int1->getId()==int2->getId() ) 
+                if ((natcmd->t_addr == nc->t_addr ||
+                     (a1 && a2 && *a1 == *a2)) &&
+                    int1->getId() == int2->getId() ) 
                 {
-                    natcmd->ignore_global=true;
-                    natcmd->nat_id=nc->nat_id;
+                    natcmd->ignore_global = true;
+                    natcmd->nat_id = nc->nat_id;
                 }
             }
 
@@ -923,23 +958,23 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
  * reassign it to the global pool of the rule #2.
  */
                     natcmd->ignore_nat=true;
-
-                    for (map<int,NATCmd*>::iterator i2=pix_comp->nat_commands.begin();
-                         i2!=pix_comp->nat_commands.end(); ++i2) 
+                    map<int,NATCmd*>::iterator i2;
+                    for (i2 = pix_comp->nat_commands.begin();
+                         i2 != pix_comp->nat_commands.end(); ++i2) 
                     {
-                        NATCmd *nc2=i2->second;
+                        NATCmd *nc2 = i2->second;
                         if (natcmd->nat_id == nc2->nat_id)
                             nc2->nat_id=nc->nat_id;
                     }
-
-                    natcmd->nat_id=nc->nat_id;
+                    natcmd->nat_id = nc->nat_id;
                 }
             }
 
             if (!natcmd->use_nat_0_0) 
             {
-                for (map<int,NATCmd*>::iterator i1=pix_comp->nat_commands.begin();
-                     i1!=pix_comp->nat_commands.end(); ++i1) 
+                map<int,NATCmd*>::iterator i1;
+                for (i1 = pix_comp->nat_commands.begin();
+                     i1 != pix_comp->nat_commands.end(); ++i1) 
                 {
                     NATCmd *nc=(*i1).second;
 /* since map nat_commands is sorted by the key, we only have to scan it
@@ -951,7 +986,6 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
  * command or use 'nat 0' command since this means we won't print
  * access-list for those rules and hense can not merge lists
  */
-
                     if (nc->ignore_nat) continue;
                     if (nc->use_nat_0_0) continue;
 
@@ -965,7 +999,6 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
  * in the previous cycle.  We can merge access lists and drop one of
  * these nat commands. We merge ACLs by assigning them the same name.
  */
-
                         natcmd->nat_acl_name = nc->nat_acl_name;
                         nc->ignore_nat_and_print_acl=true;
                     }
@@ -973,7 +1006,6 @@ bool NATCompiler_pix::mergeNATCmd::processNext()
             }
 	}
 
-
     }
     return true;
 }
@@ -1036,8 +1068,10 @@ bool  NATCompiler_pix::optimizeDefaultNAT::processNext()
  */    
     FWObject *o=osrc->front();
     string osrc_id;
-    if (FWReference::cast(o)!=NULL) osrc_id=FWReference::cast(o)->getPointerId();
-    else osrc_id=o->getId();
+    if (FWReference::cast(o)!=NULL)
+        osrc_id = FWObjectDatabase::getStringId(FWReference::cast(o)->getPointerId());
+    else
+        osrc_id = FWObjectDatabase::getStringId(o->getId());
 
     if ( ( !tsrc->isAny() && tdst->isAny()) ||
          ( !osrc->isAny() && odst->isAny() && tsrc->isAny() && tdst->isAny() )
@@ -1112,10 +1146,10 @@ bool  NATCompiler_pix::SuppressDuplicateNONATStatics::processNext()
 	Address  *odst=compiler->getFirstODst(rule);  assert(odst);
 
         nonat_static_parameters  sp;
-        sp.iface1= helper.findInterfaceByNetzone(osrc );
-        sp.iface2= helper.findInterfaceByNetzone(odst );
-        sp.addr=odst->getAddress();
-        sp.mask=odst->getNetmask();
+        sp.iface1 = helper.findInterfaceByNetzone(osrc );
+        sp.iface2 = helper.findInterfaceByNetzone(odst );
+        sp.addr = *(odst->getAddressPtr());
+        sp.mask = *(odst->getNetmaskPtr());
 
         for (deque<nonat_static_parameters>::iterator i=all_nonat_statics.begin(); 
              i!=all_nonat_statics.end();  ++i )
@@ -1135,18 +1169,17 @@ bool  NATCompiler_pix::SuppressDuplicateNONATStatics::processNext()
 NATCompiler_pix::DetectOverlap::~DetectOverlap() {};
 
 bool NATCompiler_pix::DetectOverlap::checkOverlapping(
-    const libfwbuilder::Address   &addr1,
-    const libfwbuilder::IPAddress &addr2)
+    const libfwbuilder::Address  &addr1,
+    const libfwbuilder::InetAddr &addr2)
 {
     if (AddressRange::isA(&addr1))
     {
-        const IPAddress a1=AddressRange::constcast(&addr1)->getRangeStart();
-        const IPAddress a2=AddressRange::constcast(&addr1)->getRangeEnd();
+        const InetAddr a1 = AddressRange::constcast(&addr1)->getRangeStart();
+        const InetAddr a2 = AddressRange::constcast(&addr1)->getRangeEnd();
         return (addr2==a1 || addr2==a2 || (addr2>a1 && addr2<a2));
     } else
     {
-        return addr1.getAddress() == addr2 || 
-            IPNetwork(addr1.getAddress(),addr1.getNetmask()).belongs(addr2);
+        return *(addr1.getAddressPtr()) == addr2 || addr1.belongs(addr2);
     }
 }
 
@@ -1154,12 +1187,13 @@ string NATCompiler_pix::DetectOverlap::printGlobalPoolAddress(const Address &poo
 {
     if (AddressRange::isA(&pool))
     {
-        const IPAddress a1=AddressRange::constcast(&pool)->getRangeStart();
-        const IPAddress a2=AddressRange::constcast(&pool)->getRangeEnd();
+        const InetAddr a1=AddressRange::constcast(&pool)->getRangeStart();
+        const InetAddr a2=AddressRange::constcast(&pool)->getRangeEnd();
         return a1.toString()+"-"+a2.toString();
     } else
     {
-        return pool.getAddress().toString()+"/"+pool.getNetmask().toString();
+        return pool.getAddressPtr()->toString() + "/" +
+            pool.getNetmaskPtr()->toString();
     }
 }
 
@@ -1178,19 +1212,17 @@ bool  NATCompiler_pix::DetectGlobalPoolProblems::processNext()
         if (natcmd->type!= INTERFACE) 
         {
             if (checkOverlapping(*(natcmd->t_addr),
-                                 natcmd->t_iface->getAddress()))
+                                 *(natcmd->t_iface->getAddressPtr())))
                 compiler->abort("Global pool "
                                 +printGlobalPoolAddress(*(natcmd->t_addr)) 
                                 +" overlaps with interface address. Rule "
                                 +rule->getLabel());
-            
-            IPNetwork iface_net(natcmd->t_iface->getAddress(),
-                                natcmd->t_iface->getNetmask());
 
             if (checkOverlapping(*(natcmd->t_addr),
-                                 iface_net.getBroadcastAddress()) ||
+                                 *(natcmd->t_iface->getBroadcastAddressPtr()))
+                ||
                 checkOverlapping(*(natcmd->t_addr),
-                                 iface_net.getAddress()) )
+                                 *(natcmd->t_iface->getAddressPtr())) )
                 compiler->warning("Global pool "
                                   +printGlobalPoolAddress(*(natcmd->t_addr)) 
                                   +" overlaps with broadcast address. Rule "
@@ -1268,16 +1300,16 @@ bool  NATCompiler_pix::DetectOverlappingGlobalPoolsAndStaticRules::processNext()
 
             if (iface!=NULL && iface->getId()==outa->getId()) return true;
 
-            addr.setAddress(natcmd->t_addr->getAddress());
-            addr.setNetmask(natcmd->t_addr->getNetmask());
+            addr.setAddress(*(natcmd->t_addr->getAddressPtr()));
+            addr.setNetmask(*(natcmd->t_addr->getNetmaskPtr()));
 
             if (natcmd->type== INTERFACE) 
             {
-                addr.setNetmask("255.255.255.255");
+                addr.setNetmask(InetAddr(InetAddr::getAllOnes()));
             }
 
-            if ( checkOverlapping(  addr, outa->getAddress()) ||
-                 checkOverlapping( *outa, addr.getAddress()) )
+            if ( checkOverlapping(  addr, *(outa->getAddressPtr())) ||
+                 checkOverlapping( *outa, *(addr.getAddressPtr())) )
                 compiler->abort("Global pool "
                                 +printGlobalPoolAddress(addr)
                                 +" from rule "
@@ -1314,11 +1346,11 @@ bool  NATCompiler_pix::DetectDuplicateNAT::processNext()
             Interface *int1=natcmd->t_iface;
             Interface *int2=nc->t_iface;
 
-//            IPAddress a1=natcmd->o_addr->getAddress();
-//            IPAddress a2=nc->o_addr->getAddress();
+//            InetAddr a1=natcmd->o_addr->getAddress();
+//            InetAddr a2=nc->o_addr->getAddress();
 //
-//            Netmask   m1=natcmd->o_addr->getNetmask();
-//            Netmask   m2=nc->o_addr->getNetmask();
+//            InetAddr   m1=natcmd->o_addr->getInetAddr();
+//            InetAddr   m2=nc->o_addr->getNetmask();
 
             if ( int1->getId()==int2->getId() &&
                  natcmd->o_src==nc->o_src &&
@@ -1326,25 +1358,31 @@ bool  NATCompiler_pix::DetectDuplicateNAT::processNext()
                  *(natcmd->o_srv)==*(nc->o_srv)
             )
             {
-                compiler->abort("Duplicate NAT detected: rules "
-                                +rule->getLabel()
-                                +" and "+nc->rule_label
-                                +" : "+natcmd->o_src->getAddress().toString()
-                                +"/"+natcmd->o_src->getNetmask().toString()
-                                + " "
-                                + natcmd->o_srv->getProtocolName()
-                                + natcmd->o_srv->getStr("src_range_start")+":"
-                                + natcmd->o_srv->getStr("src_range_end")+":"
-                                + " "
-                                +"->"+natcmd->o_dst->getAddress().toString()
-                                +"/"+natcmd->o_dst->getNetmask().toString()
-                                + " "
-                                + natcmd->o_srv->getStr("dst_range_start")+"/"
-                                + natcmd->o_srv->getStr("dst_range_end"));
-            }
+                ostringstream str;
+                str << "Duplicate NAT detected: rules "
+                    << rule->getLabel()
+                    << " and "<< nc->rule_label
+                    << " : "<< natcmd->o_src->getAddressPtr()->toString()
+                    << "/"<< natcmd->o_src->getNetmaskPtr()->toString()
+                    <<  " "
+                    <<  natcmd->o_srv->getProtocolName()
+                    << " "
+                    <<  TCPUDPService::cast(natcmd->o_srv)->getSrcRangeStart()
+                    << ":"
+                    <<  TCPUDPService::cast(natcmd->o_srv)->getSrcRangeEnd()
+                    << " "
+                    << "->"<< natcmd->o_dst->getAddressPtr()->toString()
+                    << "/"<< natcmd->o_dst->getNetmaskPtr()->toString()
+                    <<  " "
+                    <<  TCPUDPService::cast(natcmd->o_srv)->getDstRangeStart()
+                    << "/"
+                    <<  TCPUDPService::cast(natcmd->o_srv)->getDstRangeEnd();
+
+            compiler->abort(str.str());
         }
     }
-    return true;
+}
+return true;
 }
 
 bool  NATCompiler_pix::DetectOverlappingStatics::processNext()
@@ -1357,9 +1395,6 @@ bool  NATCompiler_pix::DetectOverlappingStatics::processNext()
     {
         StaticCmd *scmd=pix_comp->static_commands[ rule->getInt("sc_cmd") ];
 
-        IPNetwork nn1( scmd->iaddr->getAddress(), scmd->iaddr->getNetmask() );
-        IPNetwork nn2( scmd->oaddr->getAddress(), scmd->oaddr->getNetmask() );
-
         for (map<int,StaticCmd*>::iterator i1=pix_comp->static_commands.begin();
              i1!=pix_comp->static_commands.end();  i1++ )
         {
@@ -1374,32 +1409,42 @@ bool  NATCompiler_pix::DetectOverlappingStatics::processNext()
                      *(sc->tsrv) == *(scmd->tsrv) && 
                      *(sc->osrc) == *(scmd->osrc) &&
                      sc->oaddr->getId() == scmd->oaddr->getId())
-                    compiler->abort("Static NAT rules overlap or are redundant : rules "+
-                                    sc->rule+" and "+scmd->rule+" : "+
-                                    "outside address: "+
-                                    "interface "+Interface::cast(scmd->oaddr)->getLabel()+
-                                    " inside address: "+
-                                    scmd->iaddr->getAddress().toString()+"/"+
-                                    scmd->iaddr->getNetmask().toString());
-
-
+                    compiler->abort(
+                        "Static NAT rules overlap or are redundant : rules "+
+                        sc->rule+" and "+scmd->rule+" : "+
+                        "outside address: "+
+                        "interface "+Interface::cast(scmd->oaddr)->getLabel()+
+                        " inside address: "+
+                        scmd->iaddr->getAddressPtr()->toString()+"/"+
+                        scmd->iaddr->getNetmaskPtr()->toString());
             } else
             {
-                IPNetwork n1( sc->iaddr->getAddress(), sc->iaddr->getNetmask() );
-                IPNetwork n2( sc->oaddr->getAddress(), sc->oaddr->getNetmask() );
-
                 if ( *(sc->osrv) == *(scmd->osrv) && 
                      *(sc->tsrv) == *(scmd->tsrv) && 
-                     *(sc->osrc) == *(scmd->osrc) &&
-                     ( ! getOverlap(nn1,n1).empty() || ! getOverlap(nn2,n2).empty() ) )
-                    compiler->abort("Static NAT rules overlap or are redundant : rules "+
-                                    sc->rule+" and "+scmd->rule+" : "+
-                                    "outside address: "+
-                                    scmd->oaddr->getAddress().toString()+"/"+
-                                    scmd->oaddr->getNetmask().toString()+
-                                    " inside address: "+
-                                    scmd->iaddr->getAddress().toString()+"/"+
-                                    scmd->iaddr->getNetmask().toString());
+                     *(sc->osrc) == *(scmd->osrc))
+                {
+                    const InetAddrMask *ia1 =
+                        scmd->iaddr->getInetAddrMaskObjectPtr();
+                    const InetAddrMask *ia2 =
+                        sc->iaddr->getInetAddrMaskObjectPtr();
+
+                    const InetAddrMask *oa1 =
+                        scmd->oaddr->getInetAddrMaskObjectPtr();
+                    const InetAddrMask *oa2 =
+                        sc->oaddr->getInetAddrMaskObjectPtr();
+
+                    if ( ! getOverlap(*(ia1), *(ia2)).empty() ||
+                         ! getOverlap(*(oa1), *(oa2)).empty() )
+                        compiler->abort(
+                            "Static NAT rules overlap or are redundant: rules "+
+                            sc->rule+" and "+scmd->rule+" : "+
+                            "outside address: "+
+                            scmd->oaddr->getAddressPtr()->toString()+"/"+
+                            scmd->oaddr->getNetmaskPtr()->toString()+
+                            " inside address: "+
+                            scmd->iaddr->getAddressPtr()->toString()+"/"+
+                            scmd->iaddr->getNetmaskPtr()->toString());
+                }
             }
         }
     }
