@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pix.h,v 1.1 2008/03/06 06:48:59 vkurland Exp $
+  $Id: NATCompiler_pix.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -91,9 +91,9 @@ namespace fwcompiler {
         };
 
 //  first: rule->getId(), second: nonat object
-        std::map<std::string, nonat>       nonat_rules;
+        std::map<int, nonat> nonat_rules;
 //  first: interface->getId(), second: rule->getId()
-        std::map<std::string,std::string>  first_nonat_rule_id;
+        std::map<int,int> first_nonat_rule_id;
 
         libfwbuilder::RuleSet             *final_ruleset;
 
@@ -373,7 +373,7 @@ namespace fwcompiler {
         {
             protected:
             bool checkOverlapping(const libfwbuilder::Address   &a1,
-                                  const libfwbuilder::IPAddress &a2);
+                                  const libfwbuilder::InetAddr &a2);
             std::string printGlobalPoolAddress(const libfwbuilder::Address &pool);
             public:
             DetectOverlap(const std::string &n) : NATRuleProcessor(n){}
@@ -419,8 +419,8 @@ namespace fwcompiler {
             protected:
             typedef struct {
                 std::string             iface1, iface2;
-                libfwbuilder::IPAddress addr;
-                libfwbuilder::Netmask   mask;
+                libfwbuilder::InetAddr addr;
+                libfwbuilder::InetAddr mask;
             } nonat_static_parameters;
             std::deque<nonat_static_parameters> all_nonat_statics;
             public:
@@ -461,6 +461,7 @@ namespace fwcompiler {
 
 	NATCompiler_pix(libfwbuilder::FWObjectDatabase *_db,
                         const std::string &fwname,
+                        bool ipv6_policy,
                         fwcompiler::OSConfigurator *_oscnf);
 
 	virtual int  prolog();
