@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pix_v6_acls.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: PolicyCompiler_pix_v6_acls.cpp 709 2008-12-25 20:38:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -110,15 +110,13 @@ bool PolicyCompiler_pix::SplitDirection_v6::processNext()
     {
         if (rule_iface!=NULL)
         {
-            PolicyRule *r= PolicyRule::cast(
-                compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            PolicyRule *r= compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             r->setDirection(PolicyRule::Inbound);
             tmp_queue.push_back(r);
 
-            r= PolicyRule::cast(
-                compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            r= compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             r->setDirection(PolicyRule::Outbound);
@@ -214,8 +212,7 @@ bool PolicyCompiler_pix::EmulateOutboundACL_v6::processNext()
                     {
                         if ( (*i)->getId()==iface2_id ) continue;
 
-                        PolicyRule *r= PolicyRule::cast(
-                            compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                        PolicyRule *r= compiler->dbcopy->createPolicyRule();
                         compiler->temp_ruleset->add(r);
 
                         r->duplicate(rule);
@@ -306,8 +303,7 @@ bool PolicyCompiler_pix::assignRuleToInterface_v6::processNext()
                 list<FWObject*> l2=compiler->fw->getByType(Interface::TYPENAME);
                 for (list<FWObject*>::iterator i=l2.begin(); i!=l2.end(); ++i) 
                 {
-                    PolicyRule *r= PolicyRule::cast(
-                        compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                    PolicyRule *r= compiler->dbcopy->createPolicyRule();
                     compiler->temp_ruleset->add(r);
 
                     r->duplicate(rule);
