@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pix_writers.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: PolicyCompiler_pix_writers.cpp 1152 2009-07-13 15:45:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -635,7 +635,7 @@ bool PolicyCompiler_pix::PrintRule::processNext()
 
     if (compiler->fw->getOptionsObject()->getBool("pix_use_acl_remarks"))
     {
-        compiler->output << acl->addRemark( rule->getLabel() );
+        compiler->output << acl->addRemark(rule->getLabel(), rule->getComment());
     }
 
     /*
