@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: pix.cpp 585 2008-10-09 05:08:41Z vadim $
+  $Id: pix.cpp 726 2009-01-01 20:55:43Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -47,6 +47,7 @@
 #include <cstring>
 
 #include "PolicyCompiler_pix.h"
+#include "RoutingCompiler_pix.h"
 #include "NATCompiler_pix.h"
 #include "OSConfigurator_pix_os.h"
 
@@ -235,7 +236,8 @@ int main(int argc, char * const * argv)
 
 
     if (test_mode)
-        cout << "*** Running in test mode, all errors are ignored" << endl << endl;
+        cout << "*** Running in test mode, all errors are ignored"
+             << endl << endl;
 
     try
     {
@@ -435,7 +437,7 @@ int main(int argc, char * const * argv)
             list<FWObject*> ol;
             helper.expand_group_recursive_no_cache(netzone,ol);
 
-            FWObject *nz=objdb->create(ObjectGroup::TYPENAME);
+            FWObject *nz = objdb->createObjectGroup();
             assert(nz!=NULL);
             nz->setName("netzone_"+iface->getLabel());
             objdb->add(nz);
@@ -550,6 +552,22 @@ int main(int argc, char * const * argv)
         } else
             cout << " Nothing to compile in Policy \n" << flush;
 
+        RoutingCompiler_pix *r = new RoutingCompiler_pix( objdb ,
+                                                        fwobjectname ,
+                                                        false,
+                                                        oscnf);
+//                                                        oscnf , n);
+
+        if (test_mode) r->setTestMode();
+        r->setDebugLevel( dl );
+        r->setDebugRule(  drp );
+        r->setVerbose( verbose );
+
+        if ( r->prolog() > 0 ) {
+            r->compile();
+            r->epilog();
+        } else
+            cout << " Nothing to compile in Routing \n" << flush;
 
 #ifdef _WIN32
         ofstream ofile(ofname.c_str(), ios::out|ios::binary);
@@ -560,7 +578,7 @@ int main(int argc, char * const * argv)
         ofile << "!\n\
 !  This is automatically generated file. DO NOT MODIFY !\n\
 !\n\
-!  Firewall Builder  fwb_pix v" << VERSION << "-" << RELEASE_NUM << " \n\
+!  Firewall Builder  fwb_pix v" << VERSION << "-" << BUILD_NUM << " \n\
 !\n\
 !  Generated " << timestr
               << " "
@@ -641,6 +659,16 @@ int main(int argc, char * const * argv)
         ofile << n->getCompiledScript();
         
         ofile << endl;
+
+        if (r->haveErrorsAndWarnings())
+        {
+            ofile << "! Routing compiler errors and warnings:"
+                    << endl;
+            ofile << r->getErrors("! ");
+        }
+
+        ofile << r->getCompiledScript();
+
         ofile << "!" << endl;
         ofile << "! Epilog script:" << endl;
         ofile << "!" << endl;
